diff --git a/CREDITS b/CREDITS
index 83b80fcc6..4f377ea52 100644
--- a/CREDITS
+++ b/CREDITS
@@ -2,10 +2,8 @@
CREDITS
=======
-Version 2.4.0
+Version 2.4.1
-------------
-Martin Konecny (martin.konecny@sourcefabric.org)
- Role: Developer Team Lead
Denise Rigato (denise.rigato@sourcefabric.org)
Role: Software Developer
diff --git a/VERSION b/VERSION
index 42fde3a5e..e7467e459 100644
--- a/VERSION
+++ b/VERSION
@@ -1,2 +1,2 @@
PRODUCT_ID=Airtime
-PRODUCT_RELEASE=2.4.0
+PRODUCT_RELEASE=2.4.1
diff --git a/airtime_mvc/application/configs/classmap-airtime-conf.php b/airtime_mvc/application/configs/classmap-airtime-conf.php
index b5626a849..fb4284681 100644
--- a/airtime_mvc/application/configs/classmap-airtime-conf.php
+++ b/airtime_mvc/application/configs/classmap-airtime-conf.php
@@ -183,6 +183,13 @@ return array (
'BaseCcWebstreamMetadataPeer' => 'airtime/om/BaseCcWebstreamMetadataPeer.php',
'BaseCcWebstreamMetadata' => 'airtime/om/BaseCcWebstreamMetadata.php',
'BaseCcWebstreamMetadataQuery' => 'airtime/om/BaseCcWebstreamMetadataQuery.php',
+ 'CcMountNameTableMap' => 'airtime/map/CcMountNameTableMap.php',
+ 'CcMountNamePeer' => 'airtime/CcMountNamePeer.php',
+ 'CcMountName' => 'airtime/CcMountName.php',
+ 'CcMountNameQuery' => 'airtime/CcMountNameQuery.php',
+ 'BaseCcMountNamePeer' => 'airtime/om/BaseCcMountNamePeer.php',
+ 'BaseCcMountName' => 'airtime/om/BaseCcMountName.php',
+ 'BaseCcMountNameQuery' => 'airtime/om/BaseCcMountNameQuery.php',
'CcTimestampTableMap' => 'airtime/map/CcTimestampTableMap.php',
'CcTimestampPeer' => 'airtime/CcTimestampPeer.php',
'CcTimestamp' => 'airtime/CcTimestamp.php',
diff --git a/airtime_mvc/application/controllers/ApiController.php b/airtime_mvc/application/controllers/ApiController.php
index cc01e65a0..ac32ae832 100644
--- a/airtime_mvc/application/controllers/ApiController.php
+++ b/airtime_mvc/application/controllers/ApiController.php
@@ -209,6 +209,43 @@ class ApiController extends Zend_Controller_Action
}
}
+ public function onAirLightAction()
+ {
+ $this->view->layout()->disableLayout();
+ $this->_helper->viewRenderer->setNoRender(true);
+
+ $result = array();
+ $result["on_air_light"] = false;
+ $result["on_air_light_expected_status"] = false;
+ $result["station_down"] = false;
+
+ $range = Application_Model_Schedule::GetPlayOrderRange();
+
+ $isItemCurrentlyScheduled = !is_null($range["current"]) && count($range["currentShow"]) > 0 ? true : false;
+
+ $isCurrentItemPlaying = $range["current"]["media_item_played"] ? true : false;
+
+ if ($isItemCurrentlyScheduled ||
+ Application_Model_Preference::GetSourceSwitchStatus("live_dj") == "on" ||
+ Application_Model_Preference::GetSourceSwitchStatus("master_dj") == "on")
+ {
+ $result["on_air_light_expected_status"] = true;
+ }
+
+ if (($isItemCurrentlyScheduled && $isCurrentItemPlaying) ||
+ Application_Model_Preference::GetSourceSwitchStatus("live_dj") == "on" ||
+ Application_Model_Preference::GetSourceSwitchStatus("master_dj") == "on")
+ {
+ $result["on_air_light"] = true;
+ }
+
+ if ($result["on_air_light_expected_status"] != $result["on_air_light"]) {
+ $result["station_down"] = true;
+ }
+
+ echo isset($_GET['callback']) ? $_GET['callback'].'('.json_encode($result).')' : json_encode($result);
+ }
+
/**
* Retrieve the currently playing show as well as upcoming shows.
* Number of shows returned and the time interval in which to
@@ -972,23 +1009,30 @@ class ApiController extends Zend_Controller_Action
//calculated with silan by actually scanning the entire file. This
//process takes a really long time, and so we only do it in the background
//after the file has already been imported -MK
- $length = $file->getDbLength();
- if (isset($info['length'])) {
- $length = $info['length'];
- //length decimal number in seconds. Need to convert it to format
- //HH:mm:ss to get around silly PHP limitations.
- $length = Application_Common_DateHelper::secondsToPlaylistTime($length);
+ try {
+ $length = $file->getDbLength();
+ if (isset($info['length'])) {
+ $length = $info['length'];
+ //length decimal number in seconds. Need to convert it to format
+ //HH:mm:ss to get around silly PHP limitations.
+ $length = Application_Common_DateHelper::secondsToPlaylistTime($length);
+ $file->setDbLength($length);
+ }
- $file->setDbLength($length);
+ $cuein = isset($info['cuein']) ? $info['cuein'] : 0;
+ $cueout = isset($info['cueout']) ? $info['cueout'] : $length;
+
+ $file->setDbCuein($cuein);
+ $file->setDbCueout($cueout);
+ $file->setDbSilanCheck(true);
+ $file->save();
+ } catch (Exception $e) {
+ Logging::info("Failed to update silan values for ".$file->getDbTrackTitle());
+ Logging::info("File length analyzed by Silan is: ".$length);
+ //set silan_check to true so we don't attempt to re-anaylze again
+ $file->setDbSilanCheck(true);
+ $file->save();
}
-
- $cuein = isset($info['cuein']) ? $info['cuein'] : 0;
- $cueout = isset($info['cueout']) ? $info['cueout'] : $length;
-
- $file->setDbCuein($cuein);
- $file->setDbCueout($cueout);
- $file->setDbSilanCheck(true);
- $file->save();
}
$this->_helper->json->sendJson(array());
diff --git a/airtime_mvc/application/controllers/ScheduleController.php b/airtime_mvc/application/controllers/ScheduleController.php
index 42ecbf6c4..e13547c88 100644
--- a/airtime_mvc/application/controllers/ScheduleController.php
+++ b/airtime_mvc/application/controllers/ScheduleController.php
@@ -46,6 +46,17 @@ class ScheduleController extends Zend_Controller_Action
$baseUrl = Application_Common_OsPath::getBaseDir();
+ $this->view->headScript()->appendScript(
+ "var calendarPref = {};\n".
+ "calendarPref.weekStart = ".Application_Model_Preference::GetWeekStartDay().";\n".
+ "calendarPref.timestamp = ".time().";\n".
+ "calendarPref.timezoneOffset = ".date("Z").";\n".
+ "calendarPref.timeScale = '".Application_Model_Preference::GetCalendarTimeScale()."';\n".
+ "calendarPref.timeInterval = ".Application_Model_Preference::GetCalendarTimeInterval().";\n".
+ "calendarPref.weekStartDay = ".Application_Model_Preference::GetWeekStartDay().";\n".
+ "var calendarEvents = null;"
+ );
+
$this->view->headScript()->appendFile($baseUrl.'js/contextmenu/jquery.contextMenu.js?'.$CC_CONFIG['airtime_version'],'text/javascript');
//full-calendar-functions.js requires this variable, so that datePicker widget can be offset to server time instead of client time
@@ -96,16 +107,6 @@ class ScheduleController extends Zend_Controller_Action
}
$this->view->addNewShow = true;
- $this->view->headScript()->appendScript(
- "var calendarPref = {};\n".
- "calendarPref.weekStart = ".Application_Model_Preference::GetWeekStartDay().";\n".
- "calendarPref.timestamp = ".time().";\n".
- "calendarPref.timezoneOffset = ".date("Z").";\n".
- "calendarPref.timeScale = '".Application_Model_Preference::GetCalendarTimeScale()."';\n".
- "calendarPref.timeInterval = ".Application_Model_Preference::GetCalendarTimeInterval().";\n".
- "calendarPref.weekStartDay = ".Application_Model_Preference::GetWeekStartDay().";\n".
- "var calendarEvents = null;"
- );
}
public function eventFeedAction()
diff --git a/airtime_mvc/application/models/Playlist.php b/airtime_mvc/application/models/Playlist.php
index 7011a501f..7eaad0a64 100644
--- a/airtime_mvc/application/models/Playlist.php
+++ b/airtime_mvc/application/models/Playlist.php
@@ -505,11 +505,12 @@ SQL;
foreach ($p_items as $ac) {
$res = $this->insertPlaylistElement($this->buildEntry($ac, $pos));
-
// update is_playlist flag in cc_files to indicate the
// file belongs to a playlist or block (in this case a playlist)
- $db_file = CcFilesQuery::create()->findPk($ac[0], $this->con);
- $db_file->setDbIsPlaylist(true)->save($this->con);
+ if ($ac[1] == "audioclip") {
+ $db_file = CcFilesQuery::create()->findPk($ac[0], $this->con);
+ $db_file->setDbIsPlaylist(true)->save($this->con);
+ }
$pos = $pos + 1;
}
diff --git a/airtime_mvc/application/models/airtime/CcMountName.php b/airtime_mvc/application/models/airtime/CcMountName.php
new file mode 100644
index 000000000..3036dbdcd
--- /dev/null
+++ b/airtime_mvc/application/models/airtime/CcMountName.php
@@ -0,0 +1,18 @@
+addRelation('CcTimestamp', 'CcTimestamp', RelationMap::MANY_TO_ONE, array('timestamp_id' => 'id', ), 'CASCADE', null);
- $this->addRelation('CcTimestamp', 'CcTimestamp', RelationMap::MANY_TO_ONE, array('mount_name_id' => 'id', ), 'CASCADE', null);
+ $this->addRelation('CcMountName', 'CcMountName', RelationMap::MANY_TO_ONE, array('mount_name_id' => 'id', ), 'CASCADE', null);
} // buildRelations()
} // CcListenerCountTableMap
diff --git a/airtime_mvc/application/models/airtime/map/CcMountNameTableMap.php b/airtime_mvc/application/models/airtime/map/CcMountNameTableMap.php
new file mode 100644
index 000000000..f07bc5403
--- /dev/null
+++ b/airtime_mvc/application/models/airtime/map/CcMountNameTableMap.php
@@ -0,0 +1,54 @@
+setName('cc_mount_name');
+ $this->setPhpName('CcMountName');
+ $this->setClassname('CcMountName');
+ $this->setPackage('airtime');
+ $this->setUseIdGenerator(true);
+ $this->setPrimaryKeyMethodInfo('cc_mount_name_id_seq');
+ // columns
+ $this->addPrimaryKey('ID', 'DbId', 'INTEGER', true, null, null);
+ $this->addColumn('MOUNT_NAME', 'DbMountName', 'VARCHAR', true, 255, null);
+ // validators
+ } // initialize()
+
+ /**
+ * Build the RelationMap objects for this table relationships
+ */
+ public function buildRelations()
+ {
+ $this->addRelation('CcListenerCount', 'CcListenerCount', RelationMap::ONE_TO_MANY, array('id' => 'mount_name_id', ), 'CASCADE', null);
+ } // buildRelations()
+
+} // CcMountNameTableMap
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcListenerCountPeer.php b/airtime_mvc/application/models/airtime/om/BaseCcListenerCountPeer.php
index 9e3a7cb87..dad3a53b9 100644
--- a/airtime_mvc/application/models/airtime/om/BaseCcListenerCountPeer.php
+++ b/airtime_mvc/application/models/airtime/om/BaseCcListenerCountPeer.php
@@ -496,7 +496,7 @@ abstract class BaseCcListenerCountPeer {
/**
- * Returns the number of rows matching criteria, joining the related CcTimestamp table
+ * Returns the number of rows matching criteria, joining the related CcMountName table
*
* @param Criteria $criteria
* @param boolean $distinct Whether to select only distinct columns; deprecated: use Criteria->setDistinct() instead.
@@ -504,7 +504,7 @@ abstract class BaseCcListenerCountPeer {
* @param String $join_behavior the type of joins to use, defaults to Criteria::LEFT_JOIN
* @return int Number of matching rows.
*/
- public static function doCountJoinCcTimestamp(Criteria $criteria, $distinct = false, PropelPDO $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ public static function doCountJoinCcMountName(Criteria $criteria, $distinct = false, PropelPDO $con = null, $join_behavior = Criteria::LEFT_JOIN)
{
// we're going to modify criteria, so copy it first
$criteria = clone $criteria;
@@ -531,7 +531,7 @@ abstract class BaseCcListenerCountPeer {
$con = Propel::getConnection(CcListenerCountPeer::DATABASE_NAME, Propel::CONNECTION_READ);
}
- $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcTimestampPeer::ID, $join_behavior);
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
$stmt = BasePeer::doCount($criteria, $con);
@@ -612,7 +612,7 @@ abstract class BaseCcListenerCountPeer {
/**
- * Selects a collection of CcListenerCount objects pre-filled with their CcTimestamp objects.
+ * Selects a collection of CcListenerCount objects pre-filled with their CcMountName objects.
* @param Criteria $criteria
* @param PropelPDO $con
* @param String $join_behavior the type of joins to use, defaults to Criteria::LEFT_JOIN
@@ -620,7 +620,7 @@ abstract class BaseCcListenerCountPeer {
* @throws PropelException Any exceptions caught during processing will be
* rethrown wrapped into a PropelException.
*/
- public static function doSelectJoinCcTimestamp(Criteria $criteria, $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ public static function doSelectJoinCcMountName(Criteria $criteria, $con = null, $join_behavior = Criteria::LEFT_JOIN)
{
$criteria = clone $criteria;
@@ -631,9 +631,9 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addSelectColumns($criteria);
$startcol = (CcListenerCountPeer::NUM_COLUMNS - CcListenerCountPeer::NUM_LAZY_LOAD_COLUMNS);
- CcTimestampPeer::addSelectColumns($criteria);
+ CcMountNamePeer::addSelectColumns($criteria);
- $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcTimestampPeer::ID, $join_behavior);
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
$stmt = BasePeer::doSelect($criteria, $con);
$results = array();
@@ -653,19 +653,19 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addInstanceToPool($obj1, $key1);
} // if $obj1 already loaded
- $key2 = CcTimestampPeer::getPrimaryKeyHashFromRow($row, $startcol);
+ $key2 = CcMountNamePeer::getPrimaryKeyHashFromRow($row, $startcol);
if ($key2 !== null) {
- $obj2 = CcTimestampPeer::getInstanceFromPool($key2);
+ $obj2 = CcMountNamePeer::getInstanceFromPool($key2);
if (!$obj2) {
- $cls = CcTimestampPeer::getOMClass(false);
+ $cls = CcMountNamePeer::getOMClass(false);
$obj2 = new $cls();
$obj2->hydrate($row, $startcol);
- CcTimestampPeer::addInstanceToPool($obj2, $key2);
+ CcMountNamePeer::addInstanceToPool($obj2, $key2);
} // if obj2 already loaded
- // Add the $obj1 (CcListenerCount) to $obj2 (CcTimestamp)
+ // Add the $obj1 (CcListenerCount) to $obj2 (CcMountName)
$obj2->addCcListenerCount($obj1);
} // if joined row was not null
@@ -715,7 +715,7 @@ abstract class BaseCcListenerCountPeer {
$criteria->addJoin(CcListenerCountPeer::TIMESTAMP_ID, CcTimestampPeer::ID, $join_behavior);
- $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcTimestampPeer::ID, $join_behavior);
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
$stmt = BasePeer::doCount($criteria, $con);
@@ -753,12 +753,12 @@ abstract class BaseCcListenerCountPeer {
CcTimestampPeer::addSelectColumns($criteria);
$startcol3 = $startcol2 + (CcTimestampPeer::NUM_COLUMNS - CcTimestampPeer::NUM_LAZY_LOAD_COLUMNS);
- CcTimestampPeer::addSelectColumns($criteria);
- $startcol4 = $startcol3 + (CcTimestampPeer::NUM_COLUMNS - CcTimestampPeer::NUM_LAZY_LOAD_COLUMNS);
+ CcMountNamePeer::addSelectColumns($criteria);
+ $startcol4 = $startcol3 + (CcMountNamePeer::NUM_COLUMNS - CcMountNamePeer::NUM_LAZY_LOAD_COLUMNS);
$criteria->addJoin(CcListenerCountPeer::TIMESTAMP_ID, CcTimestampPeer::ID, $join_behavior);
- $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcTimestampPeer::ID, $join_behavior);
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
$stmt = BasePeer::doSelect($criteria, $con);
$results = array();
@@ -795,21 +795,21 @@ abstract class BaseCcListenerCountPeer {
$obj2->addCcListenerCount($obj1);
} // if joined row not null
- // Add objects for joined CcTimestamp rows
+ // Add objects for joined CcMountName rows
- $key3 = CcTimestampPeer::getPrimaryKeyHashFromRow($row, $startcol3);
+ $key3 = CcMountNamePeer::getPrimaryKeyHashFromRow($row, $startcol3);
if ($key3 !== null) {
- $obj3 = CcTimestampPeer::getInstanceFromPool($key3);
+ $obj3 = CcMountNamePeer::getInstanceFromPool($key3);
if (!$obj3) {
- $cls = CcTimestampPeer::getOMClass(false);
+ $cls = CcMountNamePeer::getOMClass(false);
$obj3 = new $cls();
$obj3->hydrate($row, $startcol3);
- CcTimestampPeer::addInstanceToPool($obj3, $key3);
+ CcMountNamePeer::addInstanceToPool($obj3, $key3);
} // if obj3 loaded
- // Add the $obj1 (CcListenerCount) to the collection in $obj3 (CcTimestamp)
+ // Add the $obj1 (CcListenerCount) to the collection in $obj3 (CcMountName)
$obj3->addCcListenerCount($obj1);
} // if joined row not null
@@ -856,6 +856,8 @@ abstract class BaseCcListenerCountPeer {
$con = Propel::getConnection(CcListenerCountPeer::DATABASE_NAME, Propel::CONNECTION_READ);
}
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
+
$stmt = BasePeer::doCount($criteria, $con);
if ($row = $stmt->fetch(PDO::FETCH_NUM)) {
@@ -869,7 +871,7 @@ abstract class BaseCcListenerCountPeer {
/**
- * Returns the number of rows matching criteria, joining the related CcTimestamp table
+ * Returns the number of rows matching criteria, joining the related CcMountName table
*
* @param Criteria $criteria
* @param boolean $distinct Whether to select only distinct columns; deprecated: use Criteria->setDistinct() instead.
@@ -877,7 +879,7 @@ abstract class BaseCcListenerCountPeer {
* @param String $join_behavior the type of joins to use, defaults to Criteria::LEFT_JOIN
* @return int Number of matching rows.
*/
- public static function doCountJoinAllExceptCcTimestamp(Criteria $criteria, $distinct = false, PropelPDO $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ public static function doCountJoinAllExceptCcMountName(Criteria $criteria, $distinct = false, PropelPDO $con = null, $join_behavior = Criteria::LEFT_JOIN)
{
// we're going to modify criteria, so copy it first
$criteria = clone $criteria;
@@ -904,6 +906,8 @@ abstract class BaseCcListenerCountPeer {
$con = Propel::getConnection(CcListenerCountPeer::DATABASE_NAME, Propel::CONNECTION_READ);
}
+ $criteria->addJoin(CcListenerCountPeer::TIMESTAMP_ID, CcTimestampPeer::ID, $join_behavior);
+
$stmt = BasePeer::doCount($criteria, $con);
if ($row = $stmt->fetch(PDO::FETCH_NUM)) {
@@ -940,6 +944,11 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addSelectColumns($criteria);
$startcol2 = (CcListenerCountPeer::NUM_COLUMNS - CcListenerCountPeer::NUM_LAZY_LOAD_COLUMNS);
+ CcMountNamePeer::addSelectColumns($criteria);
+ $startcol3 = $startcol2 + (CcMountNamePeer::NUM_COLUMNS - CcMountNamePeer::NUM_LAZY_LOAD_COLUMNS);
+
+ $criteria->addJoin(CcListenerCountPeer::MOUNT_NAME_ID, CcMountNamePeer::ID, $join_behavior);
+
$stmt = BasePeer::doSelect($criteria, $con);
$results = array();
@@ -958,6 +967,25 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addInstanceToPool($obj1, $key1);
} // if obj1 already loaded
+ // Add objects for joined CcMountName rows
+
+ $key2 = CcMountNamePeer::getPrimaryKeyHashFromRow($row, $startcol2);
+ if ($key2 !== null) {
+ $obj2 = CcMountNamePeer::getInstanceFromPool($key2);
+ if (!$obj2) {
+
+ $cls = CcMountNamePeer::getOMClass(false);
+
+ $obj2 = new $cls();
+ $obj2->hydrate($row, $startcol2);
+ CcMountNamePeer::addInstanceToPool($obj2, $key2);
+ } // if $obj2 already loaded
+
+ // Add the $obj1 (CcListenerCount) to the collection in $obj2 (CcMountName)
+ $obj2->addCcListenerCount($obj1);
+
+ } // if joined row is not null
+
$results[] = $obj1;
}
$stmt->closeCursor();
@@ -966,7 +994,7 @@ abstract class BaseCcListenerCountPeer {
/**
- * Selects a collection of CcListenerCount objects pre-filled with all related objects except CcTimestamp.
+ * Selects a collection of CcListenerCount objects pre-filled with all related objects except CcMountName.
*
* @param Criteria $criteria
* @param PropelPDO $con
@@ -975,7 +1003,7 @@ abstract class BaseCcListenerCountPeer {
* @throws PropelException Any exceptions caught during processing will be
* rethrown wrapped into a PropelException.
*/
- public static function doSelectJoinAllExceptCcTimestamp(Criteria $criteria, $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ public static function doSelectJoinAllExceptCcMountName(Criteria $criteria, $con = null, $join_behavior = Criteria::LEFT_JOIN)
{
$criteria = clone $criteria;
@@ -989,6 +1017,11 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addSelectColumns($criteria);
$startcol2 = (CcListenerCountPeer::NUM_COLUMNS - CcListenerCountPeer::NUM_LAZY_LOAD_COLUMNS);
+ CcTimestampPeer::addSelectColumns($criteria);
+ $startcol3 = $startcol2 + (CcTimestampPeer::NUM_COLUMNS - CcTimestampPeer::NUM_LAZY_LOAD_COLUMNS);
+
+ $criteria->addJoin(CcListenerCountPeer::TIMESTAMP_ID, CcTimestampPeer::ID, $join_behavior);
+
$stmt = BasePeer::doSelect($criteria, $con);
$results = array();
@@ -1007,6 +1040,25 @@ abstract class BaseCcListenerCountPeer {
CcListenerCountPeer::addInstanceToPool($obj1, $key1);
} // if obj1 already loaded
+ // Add objects for joined CcTimestamp rows
+
+ $key2 = CcTimestampPeer::getPrimaryKeyHashFromRow($row, $startcol2);
+ if ($key2 !== null) {
+ $obj2 = CcTimestampPeer::getInstanceFromPool($key2);
+ if (!$obj2) {
+
+ $cls = CcTimestampPeer::getOMClass(false);
+
+ $obj2 = new $cls();
+ $obj2->hydrate($row, $startcol2);
+ CcTimestampPeer::addInstanceToPool($obj2, $key2);
+ } // if $obj2 already loaded
+
+ // Add the $obj1 (CcListenerCount) to the collection in $obj2 (CcTimestamp)
+ $obj2->addCcListenerCount($obj1);
+
+ } // if joined row is not null
+
$results[] = $obj1;
}
$stmt->closeCursor();
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcMountName.php b/airtime_mvc/application/models/airtime/om/BaseCcMountName.php
new file mode 100644
index 000000000..b476f05a8
--- /dev/null
+++ b/airtime_mvc/application/models/airtime/om/BaseCcMountName.php
@@ -0,0 +1,893 @@
+id;
+ }
+
+ /**
+ * Get the [mount_name] column value.
+ *
+ * @return string
+ */
+ public function getDbMountName()
+ {
+ return $this->mount_name;
+ }
+
+ /**
+ * Set the value of [id] column.
+ *
+ * @param int $v new value
+ * @return CcMountName The current object (for fluent API support)
+ */
+ public function setDbId($v)
+ {
+ if ($v !== null) {
+ $v = (int) $v;
+ }
+
+ if ($this->id !== $v) {
+ $this->id = $v;
+ $this->modifiedColumns[] = CcMountNamePeer::ID;
+ }
+
+ return $this;
+ } // setDbId()
+
+ /**
+ * Set the value of [mount_name] column.
+ *
+ * @param string $v new value
+ * @return CcMountName The current object (for fluent API support)
+ */
+ public function setDbMountName($v)
+ {
+ if ($v !== null) {
+ $v = (string) $v;
+ }
+
+ if ($this->mount_name !== $v) {
+ $this->mount_name = $v;
+ $this->modifiedColumns[] = CcMountNamePeer::MOUNT_NAME;
+ }
+
+ return $this;
+ } // setDbMountName()
+
+ /**
+ * Indicates whether the columns in this object are only set to default values.
+ *
+ * This method can be used in conjunction with isModified() to indicate whether an object is both
+ * modified _and_ has some values set which are non-default.
+ *
+ * @return boolean Whether the columns in this object are only been set with default values.
+ */
+ public function hasOnlyDefaultValues()
+ {
+ // otherwise, everything was equal, so return TRUE
+ return true;
+ } // hasOnlyDefaultValues()
+
+ /**
+ * Hydrates (populates) the object variables with values from the database resultset.
+ *
+ * An offset (0-based "start column") is specified so that objects can be hydrated
+ * with a subset of the columns in the resultset rows. This is needed, for example,
+ * for results of JOIN queries where the resultset row includes columns from two or
+ * more tables.
+ *
+ * @param array $row The row returned by PDOStatement->fetch(PDO::FETCH_NUM)
+ * @param int $startcol 0-based offset column which indicates which restultset column to start with.
+ * @param boolean $rehydrate Whether this object is being re-hydrated from the database.
+ * @return int next starting column
+ * @throws PropelException - Any caught Exception will be rewrapped as a PropelException.
+ */
+ public function hydrate($row, $startcol = 0, $rehydrate = false)
+ {
+ try {
+
+ $this->id = ($row[$startcol + 0] !== null) ? (int) $row[$startcol + 0] : null;
+ $this->mount_name = ($row[$startcol + 1] !== null) ? (string) $row[$startcol + 1] : null;
+ $this->resetModified();
+
+ $this->setNew(false);
+
+ if ($rehydrate) {
+ $this->ensureConsistency();
+ }
+
+ return $startcol + 2; // 2 = CcMountNamePeer::NUM_COLUMNS - CcMountNamePeer::NUM_LAZY_LOAD_COLUMNS).
+
+ } catch (Exception $e) {
+ throw new PropelException("Error populating CcMountName object", $e);
+ }
+ }
+
+ /**
+ * Checks and repairs the internal consistency of the object.
+ *
+ * This method is executed after an already-instantiated object is re-hydrated
+ * from the database. It exists to check any foreign keys to make sure that
+ * the objects related to the current object are correct based on foreign key.
+ *
+ * You can override this method in the stub class, but you should always invoke
+ * the base method from the overridden method (i.e. parent::ensureConsistency()),
+ * in case your model changes.
+ *
+ * @throws PropelException
+ */
+ public function ensureConsistency()
+ {
+
+ } // ensureConsistency
+
+ /**
+ * Reloads this object from datastore based on primary key and (optionally) resets all associated objects.
+ *
+ * This will only work if the object has been saved and has a valid primary key set.
+ *
+ * @param boolean $deep (optional) Whether to also de-associated any related objects.
+ * @param PropelPDO $con (optional) The PropelPDO connection to use.
+ * @return void
+ * @throws PropelException - if this object is deleted, unsaved or doesn't have pk match in db
+ */
+ public function reload($deep = false, PropelPDO $con = null)
+ {
+ if ($this->isDeleted()) {
+ throw new PropelException("Cannot reload a deleted object.");
+ }
+
+ if ($this->isNew()) {
+ throw new PropelException("Cannot reload an unsaved object.");
+ }
+
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_READ);
+ }
+
+ // We don't need to alter the object instance pool; we're just modifying this instance
+ // already in the pool.
+
+ $stmt = CcMountNamePeer::doSelectStmt($this->buildPkeyCriteria(), $con);
+ $row = $stmt->fetch(PDO::FETCH_NUM);
+ $stmt->closeCursor();
+ if (!$row) {
+ throw new PropelException('Cannot find matching row in the database to reload object values.');
+ }
+ $this->hydrate($row, 0, true); // rehydrate
+
+ if ($deep) { // also de-associate any related objects?
+
+ $this->collCcListenerCounts = null;
+
+ } // if (deep)
+ }
+
+ /**
+ * Removes this object from datastore and sets delete attribute.
+ *
+ * @param PropelPDO $con
+ * @return void
+ * @throws PropelException
+ * @see BaseObject::setDeleted()
+ * @see BaseObject::isDeleted()
+ */
+ public function delete(PropelPDO $con = null)
+ {
+ if ($this->isDeleted()) {
+ throw new PropelException("This object has already been deleted.");
+ }
+
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+
+ $con->beginTransaction();
+ try {
+ $ret = $this->preDelete($con);
+ if ($ret) {
+ CcMountNameQuery::create()
+ ->filterByPrimaryKey($this->getPrimaryKey())
+ ->delete($con);
+ $this->postDelete($con);
+ $con->commit();
+ $this->setDeleted(true);
+ } else {
+ $con->commit();
+ }
+ } catch (PropelException $e) {
+ $con->rollBack();
+ throw $e;
+ }
+ }
+
+ /**
+ * Persists this object to the database.
+ *
+ * If the object is new, it inserts it; otherwise an update is performed.
+ * All modified related objects will also be persisted in the doSave()
+ * method. This method wraps all precipitate database operations in a
+ * single transaction.
+ *
+ * @param PropelPDO $con
+ * @return int The number of rows affected by this insert/update and any referring fk objects' save() operations.
+ * @throws PropelException
+ * @see doSave()
+ */
+ public function save(PropelPDO $con = null)
+ {
+ if ($this->isDeleted()) {
+ throw new PropelException("You cannot save an object that has been deleted.");
+ }
+
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+
+ $con->beginTransaction();
+ $isInsert = $this->isNew();
+ try {
+ $ret = $this->preSave($con);
+ if ($isInsert) {
+ $ret = $ret && $this->preInsert($con);
+ } else {
+ $ret = $ret && $this->preUpdate($con);
+ }
+ if ($ret) {
+ $affectedRows = $this->doSave($con);
+ if ($isInsert) {
+ $this->postInsert($con);
+ } else {
+ $this->postUpdate($con);
+ }
+ $this->postSave($con);
+ CcMountNamePeer::addInstanceToPool($this);
+ } else {
+ $affectedRows = 0;
+ }
+ $con->commit();
+ return $affectedRows;
+ } catch (PropelException $e) {
+ $con->rollBack();
+ throw $e;
+ }
+ }
+
+ /**
+ * Performs the work of inserting or updating the row in the database.
+ *
+ * If the object is new, it inserts it; otherwise an update is performed.
+ * All related objects are also updated in this method.
+ *
+ * @param PropelPDO $con
+ * @return int The number of rows affected by this insert/update and any referring fk objects' save() operations.
+ * @throws PropelException
+ * @see save()
+ */
+ protected function doSave(PropelPDO $con)
+ {
+ $affectedRows = 0; // initialize var to track total num of affected rows
+ if (!$this->alreadyInSave) {
+ $this->alreadyInSave = true;
+
+ if ($this->isNew() ) {
+ $this->modifiedColumns[] = CcMountNamePeer::ID;
+ }
+
+ // If this object has been modified, then save it to the database.
+ if ($this->isModified()) {
+ if ($this->isNew()) {
+ $criteria = $this->buildCriteria();
+ if ($criteria->keyContainsValue(CcMountNamePeer::ID) ) {
+ throw new PropelException('Cannot insert a value for auto-increment primary key ('.CcMountNamePeer::ID.')');
+ }
+
+ $pk = BasePeer::doInsert($criteria, $con);
+ $affectedRows = 1;
+ $this->setDbId($pk); //[IMV] update autoincrement primary key
+ $this->setNew(false);
+ } else {
+ $affectedRows = CcMountNamePeer::doUpdate($this, $con);
+ }
+
+ $this->resetModified(); // [HL] After being saved an object is no longer 'modified'
+ }
+
+ if ($this->collCcListenerCounts !== null) {
+ foreach ($this->collCcListenerCounts as $referrerFK) {
+ if (!$referrerFK->isDeleted()) {
+ $affectedRows += $referrerFK->save($con);
+ }
+ }
+ }
+
+ $this->alreadyInSave = false;
+
+ }
+ return $affectedRows;
+ } // doSave()
+
+ /**
+ * Array of ValidationFailed objects.
+ * @var array ValidationFailed[]
+ */
+ protected $validationFailures = array();
+
+ /**
+ * Gets any ValidationFailed objects that resulted from last call to validate().
+ *
+ *
+ * @return array ValidationFailed[]
+ * @see validate()
+ */
+ public function getValidationFailures()
+ {
+ return $this->validationFailures;
+ }
+
+ /**
+ * Validates the objects modified field values and all objects related to this table.
+ *
+ * If $columns is either a column name or an array of column names
+ * only those columns are validated.
+ *
+ * @param mixed $columns Column name or an array of column names.
+ * @return boolean Whether all columns pass validation.
+ * @see doValidate()
+ * @see getValidationFailures()
+ */
+ public function validate($columns = null)
+ {
+ $res = $this->doValidate($columns);
+ if ($res === true) {
+ $this->validationFailures = array();
+ return true;
+ } else {
+ $this->validationFailures = $res;
+ return false;
+ }
+ }
+
+ /**
+ * This function performs the validation work for complex object models.
+ *
+ * In addition to checking the current object, all related objects will
+ * also be validated. If all pass then true
is returned; otherwise
+ * an aggreagated array of ValidationFailed objects will be returned.
+ *
+ * @param array $columns Array of column names to validate.
+ * @return mixed true
if all validations pass; array of ValidationFailed
objets otherwise.
+ */
+ protected function doValidate($columns = null)
+ {
+ if (!$this->alreadyInValidation) {
+ $this->alreadyInValidation = true;
+ $retval = null;
+
+ $failureMap = array();
+
+
+ if (($retval = CcMountNamePeer::doValidate($this, $columns)) !== true) {
+ $failureMap = array_merge($failureMap, $retval);
+ }
+
+
+ if ($this->collCcListenerCounts !== null) {
+ foreach ($this->collCcListenerCounts as $referrerFK) {
+ if (!$referrerFK->validate($columns)) {
+ $failureMap = array_merge($failureMap, $referrerFK->getValidationFailures());
+ }
+ }
+ }
+
+
+ $this->alreadyInValidation = false;
+ }
+
+ return (!empty($failureMap) ? $failureMap : true);
+ }
+
+ /**
+ * Retrieves a field from the object by name passed in as a string.
+ *
+ * @param string $name name
+ * @param string $type The type of fieldname the $name is of:
+ * one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
+ * @return mixed Value of field.
+ */
+ public function getByName($name, $type = BasePeer::TYPE_PHPNAME)
+ {
+ $pos = CcMountNamePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
+ $field = $this->getByPosition($pos);
+ return $field;
+ }
+
+ /**
+ * Retrieves a field from the object by Position as specified in the xml schema.
+ * Zero-based.
+ *
+ * @param int $pos position in xml schema
+ * @return mixed Value of field at $pos
+ */
+ public function getByPosition($pos)
+ {
+ switch($pos) {
+ case 0:
+ return $this->getDbId();
+ break;
+ case 1:
+ return $this->getDbMountName();
+ break;
+ default:
+ return null;
+ break;
+ } // switch()
+ }
+
+ /**
+ * Exports the object as an array.
+ *
+ * You can specify the key type of the array by passing one of the class
+ * type constants.
+ *
+ * @param string $keyType (optional) One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
+ * Defaults to BasePeer::TYPE_PHPNAME.
+ * @param boolean $includeLazyLoadColumns (optional) Whether to include lazy loaded columns. Defaults to TRUE.
+ *
+ * @return array an associative array containing the field names (as keys) and field values
+ */
+ public function toArray($keyType = BasePeer::TYPE_PHPNAME, $includeLazyLoadColumns = true)
+ {
+ $keys = CcMountNamePeer::getFieldNames($keyType);
+ $result = array(
+ $keys[0] => $this->getDbId(),
+ $keys[1] => $this->getDbMountName(),
+ );
+ return $result;
+ }
+
+ /**
+ * Sets a field from the object by name passed in as a string.
+ *
+ * @param string $name peer name
+ * @param mixed $value field value
+ * @param string $type The type of fieldname the $name is of:
+ * one of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
+ * @return void
+ */
+ public function setByName($name, $value, $type = BasePeer::TYPE_PHPNAME)
+ {
+ $pos = CcMountNamePeer::translateFieldName($name, $type, BasePeer::TYPE_NUM);
+ return $this->setByPosition($pos, $value);
+ }
+
+ /**
+ * Sets a field from the object by Position as specified in the xml schema.
+ * Zero-based.
+ *
+ * @param int $pos position in xml schema
+ * @param mixed $value field value
+ * @return void
+ */
+ public function setByPosition($pos, $value)
+ {
+ switch($pos) {
+ case 0:
+ $this->setDbId($value);
+ break;
+ case 1:
+ $this->setDbMountName($value);
+ break;
+ } // switch()
+ }
+
+ /**
+ * Populates the object using an array.
+ *
+ * This is particularly useful when populating an object from one of the
+ * request arrays (e.g. $_POST). This method goes through the column
+ * names, checking to see whether a matching key exists in populated
+ * array. If so the setByName() method is called for that column.
+ *
+ * You can specify the key type of the array by additionally passing one
+ * of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME,
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM.
+ * The default key type is the column's phpname (e.g. 'AuthorId')
+ *
+ * @param array $arr An array to populate the object from.
+ * @param string $keyType The type of keys the array uses.
+ * @return void
+ */
+ public function fromArray($arr, $keyType = BasePeer::TYPE_PHPNAME)
+ {
+ $keys = CcMountNamePeer::getFieldNames($keyType);
+
+ if (array_key_exists($keys[0], $arr)) $this->setDbId($arr[$keys[0]]);
+ if (array_key_exists($keys[1], $arr)) $this->setDbMountName($arr[$keys[1]]);
+ }
+
+ /**
+ * Build a Criteria object containing the values of all modified columns in this object.
+ *
+ * @return Criteria The Criteria object containing all modified values.
+ */
+ public function buildCriteria()
+ {
+ $criteria = new Criteria(CcMountNamePeer::DATABASE_NAME);
+
+ if ($this->isColumnModified(CcMountNamePeer::ID)) $criteria->add(CcMountNamePeer::ID, $this->id);
+ if ($this->isColumnModified(CcMountNamePeer::MOUNT_NAME)) $criteria->add(CcMountNamePeer::MOUNT_NAME, $this->mount_name);
+
+ return $criteria;
+ }
+
+ /**
+ * Builds a Criteria object containing the primary key for this object.
+ *
+ * Unlike buildCriteria() this method includes the primary key values regardless
+ * of whether or not they have been modified.
+ *
+ * @return Criteria The Criteria object containing value(s) for primary key(s).
+ */
+ public function buildPkeyCriteria()
+ {
+ $criteria = new Criteria(CcMountNamePeer::DATABASE_NAME);
+ $criteria->add(CcMountNamePeer::ID, $this->id);
+
+ return $criteria;
+ }
+
+ /**
+ * Returns the primary key for this object (row).
+ * @return int
+ */
+ public function getPrimaryKey()
+ {
+ return $this->getDbId();
+ }
+
+ /**
+ * Generic method to set the primary key (id column).
+ *
+ * @param int $key Primary key.
+ * @return void
+ */
+ public function setPrimaryKey($key)
+ {
+ $this->setDbId($key);
+ }
+
+ /**
+ * Returns true if the primary key for this object is null.
+ * @return boolean
+ */
+ public function isPrimaryKeyNull()
+ {
+ return null === $this->getDbId();
+ }
+
+ /**
+ * Sets contents of passed object to values from current object.
+ *
+ * If desired, this method can also make copies of all associated (fkey referrers)
+ * objects.
+ *
+ * @param object $copyObj An object of CcMountName (or compatible) type.
+ * @param boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
+ * @throws PropelException
+ */
+ public function copyInto($copyObj, $deepCopy = false)
+ {
+ $copyObj->setDbMountName($this->mount_name);
+
+ if ($deepCopy) {
+ // important: temporarily setNew(false) because this affects the behavior of
+ // the getter/setter methods for fkey referrer objects.
+ $copyObj->setNew(false);
+
+ foreach ($this->getCcListenerCounts() as $relObj) {
+ if ($relObj !== $this) { // ensure that we don't try to copy a reference to ourselves
+ $copyObj->addCcListenerCount($relObj->copy($deepCopy));
+ }
+ }
+
+ } // if ($deepCopy)
+
+
+ $copyObj->setNew(true);
+ $copyObj->setDbId(NULL); // this is a auto-increment column, so set to default value
+ }
+
+ /**
+ * Makes a copy of this object that will be inserted as a new row in table when saved.
+ * It creates a new object filling in the simple attributes, but skipping any primary
+ * keys that are defined for the table.
+ *
+ * If desired, this method can also make copies of all associated (fkey referrers)
+ * objects.
+ *
+ * @param boolean $deepCopy Whether to also copy all rows that refer (by fkey) to the current row.
+ * @return CcMountName Clone of current object.
+ * @throws PropelException
+ */
+ public function copy($deepCopy = false)
+ {
+ // we use get_class(), because this might be a subclass
+ $clazz = get_class($this);
+ $copyObj = new $clazz();
+ $this->copyInto($copyObj, $deepCopy);
+ return $copyObj;
+ }
+
+ /**
+ * Returns a peer instance associated with this om.
+ *
+ * Since Peer classes are not to have any instance attributes, this method returns the
+ * same instance for all member of this class. The method could therefore
+ * be static, but this would prevent one from overriding the behavior.
+ *
+ * @return CcMountNamePeer
+ */
+ public function getPeer()
+ {
+ if (self::$peer === null) {
+ self::$peer = new CcMountNamePeer();
+ }
+ return self::$peer;
+ }
+
+ /**
+ * Clears out the collCcListenerCounts collection
+ *
+ * This does not modify the database; however, it will remove any associated objects, causing
+ * them to be refetched by subsequent calls to accessor method.
+ *
+ * @return void
+ * @see addCcListenerCounts()
+ */
+ public function clearCcListenerCounts()
+ {
+ $this->collCcListenerCounts = null; // important to set this to NULL since that means it is uninitialized
+ }
+
+ /**
+ * Initializes the collCcListenerCounts collection.
+ *
+ * By default this just sets the collCcListenerCounts collection to an empty array (like clearcollCcListenerCounts());
+ * however, you may wish to override this method in your stub class to provide setting appropriate
+ * to your application -- for example, setting the initial array to the values stored in database.
+ *
+ * @return void
+ */
+ public function initCcListenerCounts()
+ {
+ $this->collCcListenerCounts = new PropelObjectCollection();
+ $this->collCcListenerCounts->setModel('CcListenerCount');
+ }
+
+ /**
+ * Gets an array of CcListenerCount objects which contain a foreign key that references this object.
+ *
+ * If the $criteria is not null, it is used to always fetch the results from the database.
+ * Otherwise the results are fetched from the database the first time, then cached.
+ * Next time the same method is called without $criteria, the cached collection is returned.
+ * If this CcMountName is new, it will return
+ * an empty collection or the current collection; the criteria is ignored on a new object.
+ *
+ * @param Criteria $criteria optional Criteria object to narrow the query
+ * @param PropelPDO $con optional connection object
+ * @return PropelCollection|array CcListenerCount[] List of CcListenerCount objects
+ * @throws PropelException
+ */
+ public function getCcListenerCounts($criteria = null, PropelPDO $con = null)
+ {
+ if(null === $this->collCcListenerCounts || null !== $criteria) {
+ if ($this->isNew() && null === $this->collCcListenerCounts) {
+ // return empty collection
+ $this->initCcListenerCounts();
+ } else {
+ $collCcListenerCounts = CcListenerCountQuery::create(null, $criteria)
+ ->filterByCcMountName($this)
+ ->find($con);
+ if (null !== $criteria) {
+ return $collCcListenerCounts;
+ }
+ $this->collCcListenerCounts = $collCcListenerCounts;
+ }
+ }
+ return $this->collCcListenerCounts;
+ }
+
+ /**
+ * Returns the number of related CcListenerCount objects.
+ *
+ * @param Criteria $criteria
+ * @param boolean $distinct
+ * @param PropelPDO $con
+ * @return int Count of related CcListenerCount objects.
+ * @throws PropelException
+ */
+ public function countCcListenerCounts(Criteria $criteria = null, $distinct = false, PropelPDO $con = null)
+ {
+ if(null === $this->collCcListenerCounts || null !== $criteria) {
+ if ($this->isNew() && null === $this->collCcListenerCounts) {
+ return 0;
+ } else {
+ $query = CcListenerCountQuery::create(null, $criteria);
+ if($distinct) {
+ $query->distinct();
+ }
+ return $query
+ ->filterByCcMountName($this)
+ ->count($con);
+ }
+ } else {
+ return count($this->collCcListenerCounts);
+ }
+ }
+
+ /**
+ * Method called to associate a CcListenerCount object to this object
+ * through the CcListenerCount foreign key attribute.
+ *
+ * @param CcListenerCount $l CcListenerCount
+ * @return void
+ * @throws PropelException
+ */
+ public function addCcListenerCount(CcListenerCount $l)
+ {
+ if ($this->collCcListenerCounts === null) {
+ $this->initCcListenerCounts();
+ }
+ if (!$this->collCcListenerCounts->contains($l)) { // only add it if the **same** object is not already associated
+ $this->collCcListenerCounts[]= $l;
+ $l->setCcMountName($this);
+ }
+ }
+
+
+ /**
+ * If this collection has already been initialized with
+ * an identical criteria, it returns the collection.
+ * Otherwise if this CcMountName is new, it will return
+ * an empty collection; or if this CcMountName has previously
+ * been saved, it will retrieve related CcListenerCounts from storage.
+ *
+ * This method is protected by default in order to keep the public
+ * api reasonable. You can provide public methods for those you
+ * actually need in CcMountName.
+ *
+ * @param Criteria $criteria optional Criteria object to narrow the query
+ * @param PropelPDO $con optional connection object
+ * @param string $join_behavior optional join type to use (defaults to Criteria::LEFT_JOIN)
+ * @return PropelCollection|array CcListenerCount[] List of CcListenerCount objects
+ */
+ public function getCcListenerCountsJoinCcTimestamp($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ {
+ $query = CcListenerCountQuery::create(null, $criteria);
+ $query->joinWith('CcTimestamp', $join_behavior);
+
+ return $this->getCcListenerCounts($query, $con);
+ }
+
+ /**
+ * Clears the current object and sets all attributes to their default values
+ */
+ public function clear()
+ {
+ $this->id = null;
+ $this->mount_name = null;
+ $this->alreadyInSave = false;
+ $this->alreadyInValidation = false;
+ $this->clearAllReferences();
+ $this->resetModified();
+ $this->setNew(true);
+ $this->setDeleted(false);
+ }
+
+ /**
+ * Resets all collections of referencing foreign keys.
+ *
+ * This method is a user-space workaround for PHP's inability to garbage collect objects
+ * with circular references. This is currently necessary when using Propel in certain
+ * daemon or large-volumne/high-memory operations.
+ *
+ * @param boolean $deep Whether to also clear the references on all associated objects.
+ */
+ public function clearAllReferences($deep = false)
+ {
+ if ($deep) {
+ if ($this->collCcListenerCounts) {
+ foreach ((array) $this->collCcListenerCounts as $o) {
+ $o->clearAllReferences($deep);
+ }
+ }
+ } // if ($deep)
+
+ $this->collCcListenerCounts = null;
+ }
+
+ /**
+ * Catches calls to virtual methods
+ */
+ public function __call($name, $params)
+ {
+ if (preg_match('/get(\w+)/', $name, $matches)) {
+ $virtualColumn = $matches[1];
+ if ($this->hasVirtualColumn($virtualColumn)) {
+ return $this->getVirtualColumn($virtualColumn);
+ }
+ // no lcfirst in php<5.3...
+ $virtualColumn[0] = strtolower($virtualColumn[0]);
+ if ($this->hasVirtualColumn($virtualColumn)) {
+ return $this->getVirtualColumn($virtualColumn);
+ }
+ }
+ throw new PropelException('Call to undefined method: ' . $name);
+ }
+
+} // BaseCcMountName
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcMountNamePeer.php b/airtime_mvc/application/models/airtime/om/BaseCcMountNamePeer.php
new file mode 100644
index 000000000..af2e416b1
--- /dev/null
+++ b/airtime_mvc/application/models/airtime/om/BaseCcMountNamePeer.php
@@ -0,0 +1,742 @@
+ array ('DbId', 'DbMountName', ),
+ BasePeer::TYPE_STUDLYPHPNAME => array ('dbId', 'dbMountName', ),
+ BasePeer::TYPE_COLNAME => array (self::ID, self::MOUNT_NAME, ),
+ BasePeer::TYPE_RAW_COLNAME => array ('ID', 'MOUNT_NAME', ),
+ BasePeer::TYPE_FIELDNAME => array ('id', 'mount_name', ),
+ BasePeer::TYPE_NUM => array (0, 1, )
+ );
+
+ /**
+ * holds an array of keys for quick access to the fieldnames array
+ *
+ * first dimension keys are the type constants
+ * e.g. self::$fieldNames[BasePeer::TYPE_PHPNAME]['Id'] = 0
+ */
+ private static $fieldKeys = array (
+ BasePeer::TYPE_PHPNAME => array ('DbId' => 0, 'DbMountName' => 1, ),
+ BasePeer::TYPE_STUDLYPHPNAME => array ('dbId' => 0, 'dbMountName' => 1, ),
+ BasePeer::TYPE_COLNAME => array (self::ID => 0, self::MOUNT_NAME => 1, ),
+ BasePeer::TYPE_RAW_COLNAME => array ('ID' => 0, 'MOUNT_NAME' => 1, ),
+ BasePeer::TYPE_FIELDNAME => array ('id' => 0, 'mount_name' => 1, ),
+ BasePeer::TYPE_NUM => array (0, 1, )
+ );
+
+ /**
+ * Translates a fieldname to another type
+ *
+ * @param string $name field name
+ * @param string $fromType One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
+ * @param string $toType One of the class type constants
+ * @return string translated name of the field.
+ * @throws PropelException - if the specified name could not be found in the fieldname mappings.
+ */
+ static public function translateFieldName($name, $fromType, $toType)
+ {
+ $toNames = self::getFieldNames($toType);
+ $key = isset(self::$fieldKeys[$fromType][$name]) ? self::$fieldKeys[$fromType][$name] : null;
+ if ($key === null) {
+ throw new PropelException("'$name' could not be found in the field names of type '$fromType'. These are: " . print_r(self::$fieldKeys[$fromType], true));
+ }
+ return $toNames[$key];
+ }
+
+ /**
+ * Returns an array of field names.
+ *
+ * @param string $type The type of fieldnames to return:
+ * One of the class type constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME
+ * BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM
+ * @return array A list of field names
+ */
+
+ static public function getFieldNames($type = BasePeer::TYPE_PHPNAME)
+ {
+ if (!array_key_exists($type, self::$fieldNames)) {
+ throw new PropelException('Method getFieldNames() expects the parameter $type to be one of the class constants BasePeer::TYPE_PHPNAME, BasePeer::TYPE_STUDLYPHPNAME, BasePeer::TYPE_COLNAME, BasePeer::TYPE_FIELDNAME, BasePeer::TYPE_NUM. ' . $type . ' was given.');
+ }
+ return self::$fieldNames[$type];
+ }
+
+ /**
+ * Convenience method which changes table.column to alias.column.
+ *
+ * Using this method you can maintain SQL abstraction while using column aliases.
+ *
+ * $c->addAlias("alias1", TablePeer::TABLE_NAME);
+ * $c->addJoin(TablePeer::alias("alias1", TablePeer::PRIMARY_KEY_COLUMN), TablePeer::PRIMARY_KEY_COLUMN);
+ *
+ * @param string $alias The alias for the current table.
+ * @param string $column The column name for current table. (i.e. CcMountNamePeer::COLUMN_NAME).
+ * @return string
+ */
+ public static function alias($alias, $column)
+ {
+ return str_replace(CcMountNamePeer::TABLE_NAME.'.', $alias.'.', $column);
+ }
+
+ /**
+ * Add all the columns needed to create a new object.
+ *
+ * Note: any columns that were marked with lazyLoad="true" in the
+ * XML schema will not be added to the select list and only loaded
+ * on demand.
+ *
+ * @param Criteria $criteria object containing the columns to add.
+ * @param string $alias optional table alias
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function addSelectColumns(Criteria $criteria, $alias = null)
+ {
+ if (null === $alias) {
+ $criteria->addSelectColumn(CcMountNamePeer::ID);
+ $criteria->addSelectColumn(CcMountNamePeer::MOUNT_NAME);
+ } else {
+ $criteria->addSelectColumn($alias . '.ID');
+ $criteria->addSelectColumn($alias . '.MOUNT_NAME');
+ }
+ }
+
+ /**
+ * Returns the number of rows matching criteria.
+ *
+ * @param Criteria $criteria
+ * @param boolean $distinct Whether to select only distinct columns; deprecated: use Criteria->setDistinct() instead.
+ * @param PropelPDO $con
+ * @return int Number of matching rows.
+ */
+ public static function doCount(Criteria $criteria, $distinct = false, PropelPDO $con = null)
+ {
+ // we may modify criteria, so copy it first
+ $criteria = clone $criteria;
+
+ // We need to set the primary table name, since in the case that there are no WHERE columns
+ // it will be impossible for the BasePeer::createSelectSql() method to determine which
+ // tables go into the FROM clause.
+ $criteria->setPrimaryTableName(CcMountNamePeer::TABLE_NAME);
+
+ if ($distinct && !in_array(Criteria::DISTINCT, $criteria->getSelectModifiers())) {
+ $criteria->setDistinct();
+ }
+
+ if (!$criteria->hasSelectClause()) {
+ CcMountNamePeer::addSelectColumns($criteria);
+ }
+
+ $criteria->clearOrderByColumns(); // ORDER BY won't ever affect the count
+ $criteria->setDbName(self::DATABASE_NAME); // Set the correct dbName
+
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_READ);
+ }
+ // BasePeer returns a PDOStatement
+ $stmt = BasePeer::doCount($criteria, $con);
+
+ if ($row = $stmt->fetch(PDO::FETCH_NUM)) {
+ $count = (int) $row[0];
+ } else {
+ $count = 0; // no rows returned; we infer that means 0 matches.
+ }
+ $stmt->closeCursor();
+ return $count;
+ }
+ /**
+ * Method to select one object from the DB.
+ *
+ * @param Criteria $criteria object used to create the SELECT statement.
+ * @param PropelPDO $con
+ * @return CcMountName
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function doSelectOne(Criteria $criteria, PropelPDO $con = null)
+ {
+ $critcopy = clone $criteria;
+ $critcopy->setLimit(1);
+ $objects = CcMountNamePeer::doSelect($critcopy, $con);
+ if ($objects) {
+ return $objects[0];
+ }
+ return null;
+ }
+ /**
+ * Method to do selects.
+ *
+ * @param Criteria $criteria The Criteria object used to build the SELECT statement.
+ * @param PropelPDO $con
+ * @return array Array of selected Objects
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function doSelect(Criteria $criteria, PropelPDO $con = null)
+ {
+ return CcMountNamePeer::populateObjects(CcMountNamePeer::doSelectStmt($criteria, $con));
+ }
+ /**
+ * Prepares the Criteria object and uses the parent doSelect() method to execute a PDOStatement.
+ *
+ * Use this method directly if you want to work with an executed statement durirectly (for example
+ * to perform your own object hydration).
+ *
+ * @param Criteria $criteria The Criteria object used to build the SELECT statement.
+ * @param PropelPDO $con The connection to use
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ * @return PDOStatement The executed PDOStatement object.
+ * @see BasePeer::doSelect()
+ */
+ public static function doSelectStmt(Criteria $criteria, PropelPDO $con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_READ);
+ }
+
+ if (!$criteria->hasSelectClause()) {
+ $criteria = clone $criteria;
+ CcMountNamePeer::addSelectColumns($criteria);
+ }
+
+ // Set the correct dbName
+ $criteria->setDbName(self::DATABASE_NAME);
+
+ // BasePeer returns a PDOStatement
+ return BasePeer::doSelect($criteria, $con);
+ }
+ /**
+ * Adds an object to the instance pool.
+ *
+ * Propel keeps cached copies of objects in an instance pool when they are retrieved
+ * from the database. In some cases -- especially when you override doSelect*()
+ * methods in your stub classes -- you may need to explicitly add objects
+ * to the cache in order to ensure that the same objects are always returned by doSelect*()
+ * and retrieveByPK*() calls.
+ *
+ * @param CcMountName $value A CcMountName object.
+ * @param string $key (optional) key to use for instance map (for performance boost if key was already calculated externally).
+ */
+ public static function addInstanceToPool(CcMountName $obj, $key = null)
+ {
+ if (Propel::isInstancePoolingEnabled()) {
+ if ($key === null) {
+ $key = (string) $obj->getDbId();
+ } // if key === null
+ self::$instances[$key] = $obj;
+ }
+ }
+
+ /**
+ * Removes an object from the instance pool.
+ *
+ * Propel keeps cached copies of objects in an instance pool when they are retrieved
+ * from the database. In some cases -- especially when you override doDelete
+ * methods in your stub classes -- you may need to explicitly remove objects
+ * from the cache in order to prevent returning objects that no longer exist.
+ *
+ * @param mixed $value A CcMountName object or a primary key value.
+ */
+ public static function removeInstanceFromPool($value)
+ {
+ if (Propel::isInstancePoolingEnabled() && $value !== null) {
+ if (is_object($value) && $value instanceof CcMountName) {
+ $key = (string) $value->getDbId();
+ } elseif (is_scalar($value)) {
+ // assume we've been passed a primary key
+ $key = (string) $value;
+ } else {
+ $e = new PropelException("Invalid value passed to removeInstanceFromPool(). Expected primary key or CcMountName object; got " . (is_object($value) ? get_class($value) . ' object.' : var_export($value,true)));
+ throw $e;
+ }
+
+ unset(self::$instances[$key]);
+ }
+ } // removeInstanceFromPool()
+
+ /**
+ * Retrieves a string version of the primary key from the DB resultset row that can be used to uniquely identify a row in this table.
+ *
+ * For tables with a single-column primary key, that simple pkey value will be returned. For tables with
+ * a multi-column primary key, a serialize()d version of the primary key will be returned.
+ *
+ * @param string $key The key (@see getPrimaryKeyHash()) for this instance.
+ * @return CcMountName Found object or NULL if 1) no instance exists for specified key or 2) instance pooling has been disabled.
+ * @see getPrimaryKeyHash()
+ */
+ public static function getInstanceFromPool($key)
+ {
+ if (Propel::isInstancePoolingEnabled()) {
+ if (isset(self::$instances[$key])) {
+ return self::$instances[$key];
+ }
+ }
+ return null; // just to be explicit
+ }
+
+ /**
+ * Clear the instance pool.
+ *
+ * @return void
+ */
+ public static function clearInstancePool()
+ {
+ self::$instances = array();
+ }
+
+ /**
+ * Method to invalidate the instance pool of all tables related to cc_mount_name
+ * by a foreign key with ON DELETE CASCADE
+ */
+ public static function clearRelatedInstancePool()
+ {
+ // Invalidate objects in CcListenerCountPeer instance pool,
+ // since one or more of them may be deleted by ON DELETE CASCADE/SETNULL rule.
+ CcListenerCountPeer::clearInstancePool();
+ }
+
+ /**
+ * Retrieves a string version of the primary key from the DB resultset row that can be used to uniquely identify a row in this table.
+ *
+ * For tables with a single-column primary key, that simple pkey value will be returned. For tables with
+ * a multi-column primary key, a serialize()d version of the primary key will be returned.
+ *
+ * @param array $row PropelPDO resultset row.
+ * @param int $startcol The 0-based offset for reading from the resultset row.
+ * @return string A string version of PK or NULL if the components of primary key in result array are all null.
+ */
+ public static function getPrimaryKeyHashFromRow($row, $startcol = 0)
+ {
+ // If the PK cannot be derived from the row, return NULL.
+ if ($row[$startcol] === null) {
+ return null;
+ }
+ return (string) $row[$startcol];
+ }
+
+ /**
+ * Retrieves the primary key from the DB resultset row
+ * For tables with a single-column primary key, that simple pkey value will be returned. For tables with
+ * a multi-column primary key, an array of the primary key columns will be returned.
+ *
+ * @param array $row PropelPDO resultset row.
+ * @param int $startcol The 0-based offset for reading from the resultset row.
+ * @return mixed The primary key of the row
+ */
+ public static function getPrimaryKeyFromRow($row, $startcol = 0)
+ {
+ return (int) $row[$startcol];
+ }
+
+ /**
+ * The returned array will contain objects of the default type or
+ * objects that inherit from the default.
+ *
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function populateObjects(PDOStatement $stmt)
+ {
+ $results = array();
+
+ // set the class once to avoid overhead in the loop
+ $cls = CcMountNamePeer::getOMClass(false);
+ // populate the object(s)
+ while ($row = $stmt->fetch(PDO::FETCH_NUM)) {
+ $key = CcMountNamePeer::getPrimaryKeyHashFromRow($row, 0);
+ if (null !== ($obj = CcMountNamePeer::getInstanceFromPool($key))) {
+ // We no longer rehydrate the object, since this can cause data loss.
+ // See http://www.propelorm.org/ticket/509
+ // $obj->hydrate($row, 0, true); // rehydrate
+ $results[] = $obj;
+ } else {
+ $obj = new $cls();
+ $obj->hydrate($row);
+ $results[] = $obj;
+ CcMountNamePeer::addInstanceToPool($obj, $key);
+ } // if key exists
+ }
+ $stmt->closeCursor();
+ return $results;
+ }
+ /**
+ * Populates an object of the default type or an object that inherit from the default.
+ *
+ * @param array $row PropelPDO resultset row.
+ * @param int $startcol The 0-based offset for reading from the resultset row.
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ * @return array (CcMountName object, last column rank)
+ */
+ public static function populateObject($row, $startcol = 0)
+ {
+ $key = CcMountNamePeer::getPrimaryKeyHashFromRow($row, $startcol);
+ if (null !== ($obj = CcMountNamePeer::getInstanceFromPool($key))) {
+ // We no longer rehydrate the object, since this can cause data loss.
+ // See http://www.propelorm.org/ticket/509
+ // $obj->hydrate($row, $startcol, true); // rehydrate
+ $col = $startcol + CcMountNamePeer::NUM_COLUMNS;
+ } else {
+ $cls = CcMountNamePeer::OM_CLASS;
+ $obj = new $cls();
+ $col = $obj->hydrate($row, $startcol);
+ CcMountNamePeer::addInstanceToPool($obj, $key);
+ }
+ return array($obj, $col);
+ }
+ /**
+ * Returns the TableMap related to this peer.
+ * This method is not needed for general use but a specific application could have a need.
+ * @return TableMap
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function getTableMap()
+ {
+ return Propel::getDatabaseMap(self::DATABASE_NAME)->getTable(self::TABLE_NAME);
+ }
+
+ /**
+ * Add a TableMap instance to the database for this peer class.
+ */
+ public static function buildTableMap()
+ {
+ $dbMap = Propel::getDatabaseMap(BaseCcMountNamePeer::DATABASE_NAME);
+ if (!$dbMap->hasTable(BaseCcMountNamePeer::TABLE_NAME))
+ {
+ $dbMap->addTableObject(new CcMountNameTableMap());
+ }
+ }
+
+ /**
+ * The class that the Peer will make instances of.
+ *
+ * If $withPrefix is true, the returned path
+ * uses a dot-path notation which is tranalted into a path
+ * relative to a location on the PHP include_path.
+ * (e.g. path.to.MyClass -> 'path/to/MyClass.php')
+ *
+ * @param boolean $withPrefix Whether or not to return the path with the class name
+ * @return string path.to.ClassName
+ */
+ public static function getOMClass($withPrefix = true)
+ {
+ return $withPrefix ? CcMountNamePeer::CLASS_DEFAULT : CcMountNamePeer::OM_CLASS;
+ }
+
+ /**
+ * Method perform an INSERT on the database, given a CcMountName or Criteria object.
+ *
+ * @param mixed $values Criteria or CcMountName object containing data that is used to create the INSERT statement.
+ * @param PropelPDO $con the PropelPDO connection to use
+ * @return mixed The new primary key.
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function doInsert($values, PropelPDO $con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+
+ if ($values instanceof Criteria) {
+ $criteria = clone $values; // rename for clarity
+ } else {
+ $criteria = $values->buildCriteria(); // build Criteria from CcMountName object
+ }
+
+ if ($criteria->containsKey(CcMountNamePeer::ID) && $criteria->keyContainsValue(CcMountNamePeer::ID) ) {
+ throw new PropelException('Cannot insert a value for auto-increment primary key ('.CcMountNamePeer::ID.')');
+ }
+
+
+ // Set the correct dbName
+ $criteria->setDbName(self::DATABASE_NAME);
+
+ try {
+ // use transaction because $criteria could contain info
+ // for more than one table (I guess, conceivably)
+ $con->beginTransaction();
+ $pk = BasePeer::doInsert($criteria, $con);
+ $con->commit();
+ } catch(PropelException $e) {
+ $con->rollBack();
+ throw $e;
+ }
+
+ return $pk;
+ }
+
+ /**
+ * Method perform an UPDATE on the database, given a CcMountName or Criteria object.
+ *
+ * @param mixed $values Criteria or CcMountName object containing data that is used to create the UPDATE statement.
+ * @param PropelPDO $con The connection to use (specify PropelPDO connection object to exert more control over transactions).
+ * @return int The number of affected rows (if supported by underlying database driver).
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function doUpdate($values, PropelPDO $con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+
+ $selectCriteria = new Criteria(self::DATABASE_NAME);
+
+ if ($values instanceof Criteria) {
+ $criteria = clone $values; // rename for clarity
+
+ $comparison = $criteria->getComparison(CcMountNamePeer::ID);
+ $value = $criteria->remove(CcMountNamePeer::ID);
+ if ($value) {
+ $selectCriteria->add(CcMountNamePeer::ID, $value, $comparison);
+ } else {
+ $selectCriteria->setPrimaryTableName(CcMountNamePeer::TABLE_NAME);
+ }
+
+ } else { // $values is CcMountName object
+ $criteria = $values->buildCriteria(); // gets full criteria
+ $selectCriteria = $values->buildPkeyCriteria(); // gets criteria w/ primary key(s)
+ }
+
+ // set the correct dbName
+ $criteria->setDbName(self::DATABASE_NAME);
+
+ return BasePeer::doUpdate($selectCriteria, $criteria, $con);
+ }
+
+ /**
+ * Method to DELETE all rows from the cc_mount_name table.
+ *
+ * @return int The number of affected rows (if supported by underlying database driver).
+ */
+ public static function doDeleteAll($con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+ $affectedRows = 0; // initialize var to track total num of affected rows
+ try {
+ // use transaction because $criteria could contain info
+ // for more than one table or we could emulating ON DELETE CASCADE, etc.
+ $con->beginTransaction();
+ $affectedRows += BasePeer::doDeleteAll(CcMountNamePeer::TABLE_NAME, $con, CcMountNamePeer::DATABASE_NAME);
+ // Because this db requires some delete cascade/set null emulation, we have to
+ // clear the cached instance *after* the emulation has happened (since
+ // instances get re-added by the select statement contained therein).
+ CcMountNamePeer::clearInstancePool();
+ CcMountNamePeer::clearRelatedInstancePool();
+ $con->commit();
+ return $affectedRows;
+ } catch (PropelException $e) {
+ $con->rollBack();
+ throw $e;
+ }
+ }
+
+ /**
+ * Method perform a DELETE on the database, given a CcMountName or Criteria object OR a primary key value.
+ *
+ * @param mixed $values Criteria or CcMountName object or primary key or array of primary keys
+ * which is used to create the DELETE statement
+ * @param PropelPDO $con the connection to use
+ * @return int The number of affected rows (if supported by underlying database driver). This includes CASCADE-related rows
+ * if supported by native driver or if emulated using Propel.
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function doDelete($values, PropelPDO $con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_WRITE);
+ }
+
+ if ($values instanceof Criteria) {
+ // invalidate the cache for all objects of this type, since we have no
+ // way of knowing (without running a query) what objects should be invalidated
+ // from the cache based on this Criteria.
+ CcMountNamePeer::clearInstancePool();
+ // rename for clarity
+ $criteria = clone $values;
+ } elseif ($values instanceof CcMountName) { // it's a model object
+ // invalidate the cache for this single object
+ CcMountNamePeer::removeInstanceFromPool($values);
+ // create criteria based on pk values
+ $criteria = $values->buildPkeyCriteria();
+ } else { // it's a primary key, or an array of pks
+ $criteria = new Criteria(self::DATABASE_NAME);
+ $criteria->add(CcMountNamePeer::ID, (array) $values, Criteria::IN);
+ // invalidate the cache for this object(s)
+ foreach ((array) $values as $singleval) {
+ CcMountNamePeer::removeInstanceFromPool($singleval);
+ }
+ }
+
+ // Set the correct dbName
+ $criteria->setDbName(self::DATABASE_NAME);
+
+ $affectedRows = 0; // initialize var to track total num of affected rows
+
+ try {
+ // use transaction because $criteria could contain info
+ // for more than one table or we could emulating ON DELETE CASCADE, etc.
+ $con->beginTransaction();
+
+ $affectedRows += BasePeer::doDelete($criteria, $con);
+ CcMountNamePeer::clearRelatedInstancePool();
+ $con->commit();
+ return $affectedRows;
+ } catch (PropelException $e) {
+ $con->rollBack();
+ throw $e;
+ }
+ }
+
+ /**
+ * Validates all modified columns of given CcMountName object.
+ * If parameter $columns is either a single column name or an array of column names
+ * than only those columns are validated.
+ *
+ * NOTICE: This does not apply to primary or foreign keys for now.
+ *
+ * @param CcMountName $obj The object to validate.
+ * @param mixed $cols Column name or array of column names.
+ *
+ * @return mixed TRUE if all columns are valid or the error message of the first invalid column.
+ */
+ public static function doValidate(CcMountName $obj, $cols = null)
+ {
+ $columns = array();
+
+ if ($cols) {
+ $dbMap = Propel::getDatabaseMap(CcMountNamePeer::DATABASE_NAME);
+ $tableMap = $dbMap->getTable(CcMountNamePeer::TABLE_NAME);
+
+ if (! is_array($cols)) {
+ $cols = array($cols);
+ }
+
+ foreach ($cols as $colName) {
+ if ($tableMap->containsColumn($colName)) {
+ $get = 'get' . $tableMap->getColumn($colName)->getPhpName();
+ $columns[$colName] = $obj->$get();
+ }
+ }
+ } else {
+
+ }
+
+ return BasePeer::doValidate(CcMountNamePeer::DATABASE_NAME, CcMountNamePeer::TABLE_NAME, $columns);
+ }
+
+ /**
+ * Retrieve a single object by pkey.
+ *
+ * @param int $pk the primary key.
+ * @param PropelPDO $con the connection to use
+ * @return CcMountName
+ */
+ public static function retrieveByPK($pk, PropelPDO $con = null)
+ {
+
+ if (null !== ($obj = CcMountNamePeer::getInstanceFromPool((string) $pk))) {
+ return $obj;
+ }
+
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_READ);
+ }
+
+ $criteria = new Criteria(CcMountNamePeer::DATABASE_NAME);
+ $criteria->add(CcMountNamePeer::ID, $pk);
+
+ $v = CcMountNamePeer::doSelect($criteria, $con);
+
+ return !empty($v) > 0 ? $v[0] : null;
+ }
+
+ /**
+ * Retrieve multiple objects by pkey.
+ *
+ * @param array $pks List of primary keys
+ * @param PropelPDO $con the connection to use
+ * @throws PropelException Any exceptions caught during processing will be
+ * rethrown wrapped into a PropelException.
+ */
+ public static function retrieveByPKs($pks, PropelPDO $con = null)
+ {
+ if ($con === null) {
+ $con = Propel::getConnection(CcMountNamePeer::DATABASE_NAME, Propel::CONNECTION_READ);
+ }
+
+ $objs = null;
+ if (empty($pks)) {
+ $objs = array();
+ } else {
+ $criteria = new Criteria(CcMountNamePeer::DATABASE_NAME);
+ $criteria->add(CcMountNamePeer::ID, $pks, Criteria::IN);
+ $objs = CcMountNamePeer::doSelect($criteria, $con);
+ }
+ return $objs;
+ }
+
+} // BaseCcMountNamePeer
+
+// This is the static code needed to register the TableMap for this table with the main Propel class.
+//
+BaseCcMountNamePeer::buildTableMap();
+
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcMountNameQuery.php b/airtime_mvc/application/models/airtime/om/BaseCcMountNameQuery.php
new file mode 100644
index 000000000..52af75f38
--- /dev/null
+++ b/airtime_mvc/application/models/airtime/om/BaseCcMountNameQuery.php
@@ -0,0 +1,259 @@
+setModelAlias($modelAlias);
+ }
+ if ($criteria instanceof Criteria) {
+ $query->mergeWith($criteria);
+ }
+ return $query;
+ }
+
+ /**
+ * Find object by primary key
+ * Use instance pooling to avoid a database query if the object exists
+ *
+ * $obj = $c->findPk(12, $con);
+ *
+ * @param mixed $key Primary key to use for the query
+ * @param PropelPDO $con an optional connection object
+ *
+ * @return CcMountName|array|mixed the result, formatted by the current formatter
+ */
+ public function findPk($key, $con = null)
+ {
+ if ((null !== ($obj = CcMountNamePeer::getInstanceFromPool((string) $key))) && $this->getFormatter()->isObjectFormatter()) {
+ // the object is alredy in the instance pool
+ return $obj;
+ } else {
+ // the object has not been requested yet, or the formatter is not an object formatter
+ $criteria = $this->isKeepQuery() ? clone $this : $this;
+ $stmt = $criteria
+ ->filterByPrimaryKey($key)
+ ->getSelectStatement($con);
+ return $criteria->getFormatter()->init($criteria)->formatOne($stmt);
+ }
+ }
+
+ /**
+ * Find objects by primary key
+ *
+ * $objs = $c->findPks(array(12, 56, 832), $con);
+ *
+ * @param array $keys Primary keys to use for the query
+ * @param PropelPDO $con an optional connection object
+ *
+ * @return PropelObjectCollection|array|mixed the list of results, formatted by the current formatter
+ */
+ public function findPks($keys, $con = null)
+ {
+ $criteria = $this->isKeepQuery() ? clone $this : $this;
+ return $this
+ ->filterByPrimaryKeys($keys)
+ ->find($con);
+ }
+
+ /**
+ * Filter the query by primary key
+ *
+ * @param mixed $key Primary key to use for the query
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function filterByPrimaryKey($key)
+ {
+ return $this->addUsingAlias(CcMountNamePeer::ID, $key, Criteria::EQUAL);
+ }
+
+ /**
+ * Filter the query by a list of primary keys
+ *
+ * @param array $keys The list of primary key to use for the query
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function filterByPrimaryKeys($keys)
+ {
+ return $this->addUsingAlias(CcMountNamePeer::ID, $keys, Criteria::IN);
+ }
+
+ /**
+ * Filter the query on the id column
+ *
+ * @param int|array $dbId The value to use as filter.
+ * Accepts an associative array('min' => $minValue, 'max' => $maxValue)
+ * @param string $comparison Operator to use for the column comparison, defaults to Criteria::EQUAL
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function filterByDbId($dbId = null, $comparison = null)
+ {
+ if (is_array($dbId) && null === $comparison) {
+ $comparison = Criteria::IN;
+ }
+ return $this->addUsingAlias(CcMountNamePeer::ID, $dbId, $comparison);
+ }
+
+ /**
+ * Filter the query on the mount_name column
+ *
+ * @param string $dbMountName The value to use as filter.
+ * Accepts wildcards (* and % trigger a LIKE)
+ * @param string $comparison Operator to use for the column comparison, defaults to Criteria::EQUAL
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function filterByDbMountName($dbMountName = null, $comparison = null)
+ {
+ if (null === $comparison) {
+ if (is_array($dbMountName)) {
+ $comparison = Criteria::IN;
+ } elseif (preg_match('/[\%\*]/', $dbMountName)) {
+ $dbMountName = str_replace('*', '%', $dbMountName);
+ $comparison = Criteria::LIKE;
+ }
+ }
+ return $this->addUsingAlias(CcMountNamePeer::MOUNT_NAME, $dbMountName, $comparison);
+ }
+
+ /**
+ * Filter the query by a related CcListenerCount object
+ *
+ * @param CcListenerCount $ccListenerCount the related object to use as filter
+ * @param string $comparison Operator to use for the column comparison, defaults to Criteria::EQUAL
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function filterByCcListenerCount($ccListenerCount, $comparison = null)
+ {
+ return $this
+ ->addUsingAlias(CcMountNamePeer::ID, $ccListenerCount->getDbMountNameId(), $comparison);
+ }
+
+ /**
+ * Adds a JOIN clause to the query using the CcListenerCount relation
+ *
+ * @param string $relationAlias optional alias for the relation
+ * @param string $joinType Accepted values are null, 'left join', 'right join', 'inner join'
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function joinCcListenerCount($relationAlias = '', $joinType = Criteria::INNER_JOIN)
+ {
+ $tableMap = $this->getTableMap();
+ $relationMap = $tableMap->getRelation('CcListenerCount');
+
+ // create a ModelJoin object for this join
+ $join = new ModelJoin();
+ $join->setJoinType($joinType);
+ $join->setRelationMap($relationMap, $this->useAliasInSQL ? $this->getModelAlias() : null, $relationAlias);
+ if ($previousJoin = $this->getPreviousJoin()) {
+ $join->setPreviousJoin($previousJoin);
+ }
+
+ // add the ModelJoin to the current object
+ if($relationAlias) {
+ $this->addAlias($relationAlias, $relationMap->getRightTable()->getName());
+ $this->addJoinObject($join, $relationAlias);
+ } else {
+ $this->addJoinObject($join, 'CcListenerCount');
+ }
+
+ return $this;
+ }
+
+ /**
+ * Use the CcListenerCount relation CcListenerCount object
+ *
+ * @see useQuery()
+ *
+ * @param string $relationAlias optional alias for the relation,
+ * to be used as main alias in the secondary query
+ * @param string $joinType Accepted values are null, 'left join', 'right join', 'inner join'
+ *
+ * @return CcListenerCountQuery A secondary query class using the current class as primary query
+ */
+ public function useCcListenerCountQuery($relationAlias = '', $joinType = Criteria::INNER_JOIN)
+ {
+ return $this
+ ->joinCcListenerCount($relationAlias, $joinType)
+ ->useQuery($relationAlias ? $relationAlias : 'CcListenerCount', 'CcListenerCountQuery');
+ }
+
+ /**
+ * Exclude object from result
+ *
+ * @param CcMountName $ccMountName Object to remove from the list of results
+ *
+ * @return CcMountNameQuery The current query, for fluid interface
+ */
+ public function prune($ccMountName = null)
+ {
+ if ($ccMountName) {
+ $this->addUsingAlias(CcMountNamePeer::ID, $ccMountName->getDbId(), Criteria::NOT_EQUAL);
+ }
+
+ return $this;
+ }
+
+} // BaseCcMountNameQuery
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcTimestamp.php b/airtime_mvc/application/models/airtime/om/BaseCcTimestamp.php
index 5ede5b73c..d61b8e513 100644
--- a/airtime_mvc/application/models/airtime/om/BaseCcTimestamp.php
+++ b/airtime_mvc/application/models/airtime/om/BaseCcTimestamp.php
@@ -861,6 +861,31 @@ abstract class BaseCcTimestamp extends BaseObject implements Persistent
}
}
+
+ /**
+ * If this collection has already been initialized with
+ * an identical criteria, it returns the collection.
+ * Otherwise if this CcTimestamp is new, it will return
+ * an empty collection; or if this CcTimestamp has previously
+ * been saved, it will retrieve related CcListenerCounts from storage.
+ *
+ * This method is protected by default in order to keep the public
+ * api reasonable. You can provide public methods for those you
+ * actually need in CcTimestamp.
+ *
+ * @param Criteria $criteria optional Criteria object to narrow the query
+ * @param PropelPDO $con optional connection object
+ * @param string $join_behavior optional join type to use (defaults to Criteria::LEFT_JOIN)
+ * @return PropelCollection|array CcListenerCount[] List of CcListenerCount objects
+ */
+ public function getCcListenerCountsJoinCcMountName($criteria = null, $con = null, $join_behavior = Criteria::LEFT_JOIN)
+ {
+ $query = CcListenerCountQuery::create(null, $criteria);
+ $query->joinWith('CcMountName', $join_behavior);
+
+ return $this->getCcListenerCounts($query, $con);
+ }
+
/**
* Clears the current object and sets all attributes to their default values
*/
diff --git a/airtime_mvc/application/services/CalendarService.php b/airtime_mvc/application/services/CalendarService.php
index d0091d589..b0e1ad865 100644
--- a/airtime_mvc/application/services/CalendarService.php
+++ b/airtime_mvc/application/services/CalendarService.php
@@ -45,11 +45,16 @@ class Application_Service_CalendarService
if ($this->ccShowInstance->isRecorded()) {
$ccFile = $this->ccShowInstance->getCcFiles();
-
- $menu["view_recorded"] = array(
- "name" => _("View Recorded File Metadata"),
- "icon" => "overview",
- "url" => $baseUrl."library/edit-file-md/id/".$ccFile->getDbId());
+ if (!isset($ccFile)) {
+ $menu["error when recording"] = array (
+ "name" => _("Record file doesn't exist"),
+ "icon" => "error");
+ }else {
+ $menu["view_recorded"] = array(
+ "name" => _("View Recorded File Metadata"),
+ "icon" => "overview",
+ "url" => $baseUrl."library/edit-file-md/id/".$ccFile->getDbId());
+ }
//recorded show can be uploaded to soundcloud
if (Application_Model_Preference::GetUploadToSoundcloudOption()) {
diff --git a/airtime_mvc/application/services/SchedulerService.php b/airtime_mvc/application/services/SchedulerService.php
index 7ab662c5c..c1dd6fc1f 100644
--- a/airtime_mvc/application/services/SchedulerService.php
+++ b/airtime_mvc/application/services/SchedulerService.php
@@ -248,22 +248,24 @@ class Application_Service_SchedulerService
}
} //foreach linked instance
- $insert_sql = "INSERT INTO cc_schedule (starts, ends, ".
- "clip_length, fade_in, fade_out, cue_in, cue_out, ".
- "file_id, stream_id, instance_id, position) VALUES ".
- implode($values, ",");
+ if (!empty($values)) {
+ $insert_sql = "INSERT INTO cc_schedule (starts, ends, ".
+ "clip_length, fade_in, fade_out, cue_in, cue_out, ".
+ "file_id, stream_id, instance_id, position) VALUES ".
+ implode($values, ",");
- Application_Common_Database::prepareAndExecute(
- $insert_sql, array(), Application_Common_Database::EXECUTE);
+ Application_Common_Database::prepareAndExecute(
+ $insert_sql, array(), Application_Common_Database::EXECUTE);
- //update time_filled in cc_show_instances
- $now = gmdate("Y-m-d H:i:s");
- $update_sql = "UPDATE cc_show_instances SET ".
- "time_filled = '{$timeFilled}', ".
- "last_scheduled = '{$now}' ".
- "WHERE show_id = {$ccShow->getDbId()}";
- Application_Common_Database::prepareAndExecute(
- $update_sql, array(), Application_Common_Database::EXECUTE);
+ //update time_filled in cc_show_instances
+ $now = gmdate("Y-m-d H:i:s");
+ $update_sql = "UPDATE cc_show_instances SET ".
+ "time_filled = '{$timeFilled}', ".
+ "last_scheduled = '{$now}' ".
+ "WHERE show_id = {$ccShow->getDbId()}";
+ Application_Common_Database::prepareAndExecute(
+ $update_sql, array(), Application_Common_Database::EXECUTE);
+ }
} //if at least one linked instance has content
}
diff --git a/airtime_mvc/application/services/ShowFormService.php b/airtime_mvc/application/services/ShowFormService.php
index 6b3e67239..c651c8ebd 100644
--- a/airtime_mvc/application/services/ShowFormService.php
+++ b/airtime_mvc/application/services/ShowFormService.php
@@ -441,7 +441,7 @@ class Application_Service_ShowFormService
$rebroadcast = true;
$absRebroadcast = true;
- if ($formData["add_show_rebroadcast"]) {
+ if (isset($formData["add_show_rebroadcast"]) && $formData["add_show_rebroadcast"]) {
$formData["add_show_duration"] = Application_Service_ShowService::formatShowDuration(
$formData["add_show_duration"]);
$absRebroadcast = $forms["abs_rebroadcast"]->isValid($formData);
diff --git a/airtime_mvc/application/services/ShowService.php b/airtime_mvc/application/services/ShowService.php
index 3efe45e0f..f5bed073e 100644
--- a/airtime_mvc/application/services/ShowService.php
+++ b/airtime_mvc/application/services/ShowService.php
@@ -655,15 +655,16 @@ SQL;
->filterByDbDay($dayOfWeek)
->findOne();
- $lastShowStartDT->setTimeZone(new DateTimeZone(
- $ccShowDay->getDbTimezone()));
- $lastShowEndDT = Application_Service_CalendarService::addDeltas(
- $lastShowStartDT, 1, 0);
+ if (isset($ccShowDay)) {
+ $lastShowStartDT->setTimeZone(new DateTimeZone(
+ $ccShowDay->getDbTimezone()));
+ $lastShowEndDT = Application_Service_CalendarService::addDeltas(
+ $lastShowStartDT, 1, 0);
- $ccShowDay
- ->setDbLastShow($lastShowEndDT->format("Y-m-d"))
- ->save();
-
+ $ccShowDay
+ ->setDbLastShow($lastShowEndDT->format("Y-m-d"))
+ ->save();
+ }
}
//remove the old repeating deleted instances.
@@ -872,6 +873,7 @@ SQL;
private function createWeeklyRepeatInstances($showDay, $populateUntil,
$repeatType, $repeatInterval, $daysAdded=null)
{
+
$show_id = $showDay->getDbShowId();
$first_show = $showDay->getDbFirstShow(); //non-UTC
$last_show = $showDay->getDbLastShow(); //non-UTC
@@ -894,10 +896,9 @@ SQL;
$utcLastShowDateTime = $last_show ?
Application_Common_DateHelper::ConvertToUtcDateTime($last_show, $timezone) : null;
- $utcStartDateTime = new DateTime("now");
$previousDate = clone $start;
- foreach ($datePeriod as $date) {
+ foreach ($datePeriod as $date) {
list($utcStartDateTime, $utcEndDateTime) = $this->createUTCStartEndDateTime(
$date, $duration);
/*
@@ -911,6 +912,7 @@ SQL;
( is_null($utcLastShowDateTime) ||
$utcStartDateTime->format("Y-m-d H:i:s") < $utcLastShowDateTime->format("Y-m-d H:i:s")) ) {
+ $lastCreatedShow = clone $utcStartDateTime;
/* There may not always be an instance when editing a show
* This will be the case when we are adding a new show day to
* a repeating show
@@ -954,12 +956,19 @@ SQL;
$previousDate = clone $date;
}
- /* Set UTC to local time before setting the next repeat date. If we don't
- * the next repeat date might be scheduled for the following day
+ /* We need to set the next populate date for repeat shows so when a user
+ * moves forward in the calendar we know when to start generating new
+ * show instances.
+ * If $utcStartDateTime is not set then we know zero new shows were
+ * created and we shouldn't update the next populate date.
*/
- $utcStartDateTime->setTimezone(new DateTimeZone(Application_Model_Preference::GetTimezone()));
- $nextDate = $utcStartDateTime->add($repeatInterval);
- $this->setNextRepeatingShowDate($nextDate->format("Y-m-d"), $day, $show_id);
+ if (isset($lastCreatedShow)) {
+ /* Set UTC to local time before setting the next repeat date. If we don't
+ * the next repeat date might be scheduled for the following day */
+ $lastCreatedShow->setTimezone(new DateTimeZone(Application_Model_Preference::GetTimezone()));
+ $nextDate = $lastCreatedShow->add($repeatInterval);
+ $this->setNextRepeatingShowDate($nextDate->format("Y-m-d"), $day, $show_id);
+ }
}
private function createMonthlyRepeatInstances($showDay, $populateUntil)
@@ -1001,6 +1010,7 @@ SQL;
( is_null($utcLastShowDateTime) ||
$utcStartDateTime->getTimestamp() < $utcLastShowDateTime->getTimestamp()) ) {
+ $lastCreatedShow = clone $utcStartDateTime;
/* There may not always be an instance when editing a show
* This will be the case when we are adding a new show day to
* a repeating show
diff --git a/airtime_mvc/application/views/scripts/playlist/update.phtml b/airtime_mvc/application/views/scripts/playlist/update.phtml
index 38558d760..0171efafa 100644
--- a/airtime_mvc/application/views/scripts/playlist/update.phtml
+++ b/airtime_mvc/application/views/scripts/playlist/update.phtml
@@ -8,6 +8,10 @@ $nextFileUrl = null;
if ($item['type'] == 2) {
$bl= new Application_Model_Block($item['item_id']);
$staticBlock = $bl->isStatic();
+ $fileUrl = null;
+}
+else if ($item['type'] == 1) {
+ $fileUrl = null;
}
else if ($item['type'] == 0) {
$audiofile = Application_Model_StoredFile::RecallById($item['item_id']);
@@ -16,12 +20,12 @@ else if ($item['type'] == 0) {
if (($i < count($items) -1) && ($items[$i+1]['type'] == 0)) {
$nextAudiofile = Application_Model_StoredFile::RecallById($items[$i+1]['item_id']);
- $nextFileUrl = $nextAudiofile->getFileUrl();
+ $nextFileUrl = $nextAudiofile->getFileUrl();
}
?>
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcListenerCount.php b/airtime_mvc/application/models/airtime/om/BaseCcListenerCount.php
index 04d4b60f3..42c435123 100644
--- a/airtime_mvc/application/models/airtime/om/BaseCcListenerCount.php
+++ b/airtime_mvc/application/models/airtime/om/BaseCcListenerCount.php
@@ -54,9 +54,9 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
protected $aCcTimestamp;
/**
- * @var CcTimestamp
+ * @var CcMountName
*/
- protected $aCcTimestamp;
+ protected $aCcMountName;
/**
* Flag to prevent endless save loop, if this object is referenced
@@ -173,8 +173,8 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
$this->modifiedColumns[] = CcListenerCountPeer::MOUNT_NAME_ID;
}
- if ($this->aCcTimestamp !== null && $this->aCcTimestamp->getDbId() !== $v) {
- $this->aCcTimestamp = null;
+ if ($this->aCcMountName !== null && $this->aCcMountName->getDbId() !== $v) {
+ $this->aCcMountName = null;
}
return $this;
@@ -270,8 +270,8 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
if ($this->aCcTimestamp !== null && $this->timestamp_id !== $this->aCcTimestamp->getDbId()) {
$this->aCcTimestamp = null;
}
- if ($this->aCcTimestamp !== null && $this->mount_name_id !== $this->aCcTimestamp->getDbId()) {
- $this->aCcTimestamp = null;
+ if ($this->aCcMountName !== null && $this->mount_name_id !== $this->aCcMountName->getDbId()) {
+ $this->aCcMountName = null;
}
} // ensureConsistency
@@ -313,7 +313,7 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
if ($deep) { // also de-associate any related objects?
$this->aCcTimestamp = null;
- $this->aCcTimestamp = null;
+ $this->aCcMountName = null;
} // if (deep)
}
@@ -436,11 +436,11 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
$this->setCcTimestamp($this->aCcTimestamp);
}
- if ($this->aCcTimestamp !== null) {
- if ($this->aCcTimestamp->isModified() || $this->aCcTimestamp->isNew()) {
- $affectedRows += $this->aCcTimestamp->save($con);
+ if ($this->aCcMountName !== null) {
+ if ($this->aCcMountName->isModified() || $this->aCcMountName->isNew()) {
+ $affectedRows += $this->aCcMountName->save($con);
}
- $this->setCcTimestamp($this->aCcTimestamp);
+ $this->setCcMountName($this->aCcMountName);
}
if ($this->isNew() ) {
@@ -543,9 +543,9 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
}
}
- if ($this->aCcTimestamp !== null) {
- if (!$this->aCcTimestamp->validate($columns)) {
- $failureMap = array_merge($failureMap, $this->aCcTimestamp->getValidationFailures());
+ if ($this->aCcMountName !== null) {
+ if (!$this->aCcMountName->validate($columns)) {
+ $failureMap = array_merge($failureMap, $this->aCcMountName->getValidationFailures());
}
}
@@ -633,8 +633,8 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
if (null !== $this->aCcTimestamp) {
$result['CcTimestamp'] = $this->aCcTimestamp->toArray($keyType, $includeLazyLoadColumns, true);
}
- if (null !== $this->aCcTimestamp) {
- $result['CcTimestamp'] = $this->aCcTimestamp->toArray($keyType, $includeLazyLoadColumns, true);
+ if (null !== $this->aCcMountName) {
+ $result['CcMountName'] = $this->aCcMountName->toArray($keyType, $includeLazyLoadColumns, true);
}
}
return $result;
@@ -879,13 +879,13 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
}
/**
* Declares an association between this object and a CcTimestamp object.
*
- * @param CcTimestamp $v
+ * @param CcMountName $v
* @return CcListenerCount The current object (for fluent API support)
* @throws PropelException
*/
- public function setCcTimestamp(CcTimestamp $v = null)
+ public function setCcMountName(CcMountName $v = null)
{
if ($v === null) {
$this->setDbMountNameId(NULL);
@@ -893,10 +893,10 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
$this->setDbMountNameId($v->getDbId());
}
- $this->aCcTimestamp = $v;
+ $this->aCcMountName = $v;
// Add binding for other direction of this n:n relationship.
// If this object has already been added to the CcTimestamp object, it will not be re-added.
if ($v !== null) {
$v->addCcListenerCount($this);
}
@@ -906,25 +906,25 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
/**
- * Get the associated CcTimestamp object
+ * Get the associated CcMountName object
*
* @param PropelPDO Optional Connection object.
- * @return CcTimestamp The associated CcTimestamp object.
+ * @return CcMountName The associated CcMountName object.
* @throws PropelException
*/
- public function getCcTimestamp(PropelPDO $con = null)
+ public function getCcMountName(PropelPDO $con = null)
{
- if ($this->aCcTimestamp === null && ($this->mount_name_id !== null)) {
- $this->aCcTimestamp = CcTimestampQuery::create()->findPk($this->mount_name_id, $con);
+ if ($this->aCcMountName === null && ($this->mount_name_id !== null)) {
+ $this->aCcMountName = CcMountNameQuery::create()->findPk($this->mount_name_id, $con);
/* The following can be used additionally to
guarantee the related object contains a reference
to this object. This level of coupling may, however, be
undesirable since it could result in an only partially populated collection
in the referenced object.
- $this->aCcTimestamp->addCcListenerCounts($this);
+ $this->aCcMountName->addCcListenerCounts($this);
*/
}
- return $this->aCcTimestamp;
+ return $this->aCcMountName;
}
/**
@@ -959,7 +959,7 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
} // if ($deep)
$this->aCcTimestamp = null;
- $this->aCcTimestamp = null;
+ $this->aCcMountName = null;
}
/**
@@ -879,13 +879,13 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
}
/**
- * Declares an association between this object and a CcTimestamp object.
+ * Declares an association between this object and a CcMountName object.
*
@@ -893,10 +893,10 @@ abstract class BaseCcListenerCount extends BaseObject implements Persistent
// Add binding for other direction of this n:n relationship.
- // If this object has already been added to the CcTimestamp object, it will not be re-added.
+ // If this object has already been added to the CcMountName object, it will not be re-added.
if ($v !== null) {
$v->addCcListenerCount($this);
diff --git a/airtime_mvc/application/models/airtime/om/BaseCcListenerCountQuery.php b/airtime_mvc/application/models/airtime/om/BaseCcListenerCountQuery.php
index ed04cd146..30c702e6e 100644
--- a/airtime_mvc/application/models/airtime/om/BaseCcListenerCountQuery.php
+++ b/airtime_mvc/application/models/airtime/om/BaseCcListenerCountQuery.php
@@ -24,9 +24,9 @@
* @method CcListenerCountQuery rightJoinCcTimestamp($relationAlias = '') Adds a RIGHT JOIN clause to the query using the CcTimestamp relation
* @method CcListenerCountQuery innerJoinCcTimestamp($relationAlias = '') Adds a INNER JOIN clause to the query using the CcTimestamp relation
*
* @method CcListenerCountQuery leftJoinCcTimestamp($relationAlias = '') Adds a LEFT JOIN clause to the query using the CcTimestamp relation
* @method CcListenerCountQuery rightJoinCcTimestamp($relationAlias = '') Adds a RIGHT JOIN clause to the query using the CcTimestamp relation
* @method CcListenerCountQuery innerJoinCcTimestamp($relationAlias = '') Adds a INNER JOIN clause to the query using the CcTimestamp relation
*
* @method CcListenerCount findOne(PropelPDO $con = null) Return the first CcListenerCount matching the query
* @method CcListenerCount findOneOrCreate(PropelPDO $con = null) Return the first CcListenerCount matching the query, or a new CcListenerCount object populated from the query conditions when no match is found
@@ -324,31 +324,31 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
}
/**
* Filter the query by a related CcTimestamp object
*
* @param CcTimestamp $ccTimestamp the related object to use as filter
* @param string $comparison Operator to use for the column comparison, defaults to Criteria::EQUAL
*
* @return CcListenerCountQuery The current query, for fluid interface
*/
- public function filterByCcTimestamp($ccTimestamp, $comparison = null)
+ public function filterByCcMountName($ccMountName, $comparison = null)
{
return $this
- ->addUsingAlias(CcListenerCountPeer::MOUNT_NAME_ID, $ccTimestamp->getDbId(), $comparison);
+ ->addUsingAlias(CcListenerCountPeer::MOUNT_NAME_ID, $ccMountName->getDbId(), $comparison);
}
/**
* Adds a JOIN clause to the query using the CcTimestamp relation
*
* @param string $relationAlias optional alias for the relation
* @param string $joinType Accepted values are null, 'left join', 'right join', 'inner join'
*
* @return CcListenerCountQuery The current query, for fluid interface
*/
- public function joinCcTimestamp($relationAlias = '', $joinType = Criteria::INNER_JOIN)
+ public function joinCcMountName($relationAlias = '', $joinType = Criteria::INNER_JOIN)
{
$tableMap = $this->getTableMap();
- $relationMap = $tableMap->getRelation('CcTimestamp');
+ $relationMap = $tableMap->getRelation('CcMountName');
// create a ModelJoin object for this join
$join = new ModelJoin();
@@ -363,14 +363,14 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
$this->addAlias($relationAlias, $relationMap->getRightTable()->getName());
$this->addJoinObject($join, $relationAlias);
} else {
- $this->addJoinObject($join, 'CcTimestamp');
+ $this->addJoinObject($join, 'CcMountName');
}
return $this;
}
/**
- * Use the CcTimestamp relation CcTimestamp object
+ * Use the CcMountName relation CcMountName object
*
* @see useQuery()
*
@@ -378,13 +378,13 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
* to be used as main alias in the secondary query
* @param string $joinType Accepted values are null, 'left join', 'right join', 'inner join'
*
* @return CcTimestampQuery A secondary query class using the current class as primary query
*/
- public function useCcTimestampQuery($relationAlias = '', $joinType = Criteria::INNER_JOIN)
+ public function useCcMountNameQuery($relationAlias = '', $joinType = Criteria::INNER_JOIN)
{
return $this
- ->joinCcTimestamp($relationAlias, $joinType)
- ->useQuery($relationAlias ? $relationAlias : 'CcTimestamp', 'CcTimestampQuery');
+ ->joinCcMountName($relationAlias, $joinType)
+ ->useQuery($relationAlias ? $relationAlias : 'CcMountName', 'CcMountNameQuery');
}
/**
@@ -24,9 +24,9 @@
* @method CcListenerCountQuery innerJoinCcTimestamp($relationAlias = '') Adds a INNER JOIN clause to the query using the CcTimestamp relation
*
- * @method CcListenerCountQuery leftJoinCcTimestamp($relationAlias = '') Adds a LEFT JOIN clause to the query using the CcTimestamp relation
- * @method CcListenerCountQuery rightJoinCcTimestamp($relationAlias = '') Adds a RIGHT JOIN clause to the query using the CcTimestamp relation
- * @method CcListenerCountQuery innerJoinCcTimestamp($relationAlias = '') Adds a INNER JOIN clause to the query using the CcTimestamp relation
+ * @method CcListenerCountQuery leftJoinCcMountName($relationAlias = '') Adds a LEFT JOIN clause to the query using the CcMountName relation
+ * @method CcListenerCountQuery rightJoinCcMountName($relationAlias = '') Adds a RIGHT JOIN clause to the query using the CcMountName relation
+ * @method CcListenerCountQuery innerJoinCcMountName($relationAlias = '') Adds a INNER JOIN clause to the query using the CcMountName relation
*
* @method CcListenerCount findOne(PropelPDO $con = null) Return the first CcListenerCount matching the query
@@ -324,31 +324,31 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
}
/**
- * Filter the query by a related CcTimestamp object
+ * Filter the query by a related CcMountName object
*
@@ -324,31 +324,31 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
*
- * @param CcTimestamp $ccTimestamp the related object to use as filter
+ * @param CcMountName $ccMountName the related object to use as filter
* @param string $comparison Operator to use for the column comparison, defaults to Criteria::EQUAL
*
@@ -324,31 +324,31 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
}
/**
- * Adds a JOIN clause to the query using the CcTimestamp relation
+ * Adds a JOIN clause to the query using the CcMountName relation
*
* @param string $relationAlias optional alias for the relation
@@ -378,13 +378,13 @@ abstract class BaseCcListenerCountQuery extends ModelCriteria
* @param string $joinType Accepted values are null, 'left join', 'right join', 'inner join'
*
- * @return CcTimestampQuery A secondary query class using the current class as primary query
+ * @return CcMountNameQuery A secondary query class using the current class as primary query
*/